/* 
 * Copyright (c) 2010
 * Texas Instruments
 *
 *  All rights reserved.  Property of Texas Instruments
 *  Restricted rights to use, duplicate or disclose this code are
 *  granted through contract.
 * 
 * */
/*
 * ======== Stream.xs ========
 *
 */

var List = null;
var DriverTypes = null;
var DriverAdapter = null;
var DriverTable = null;
var Memory = null;
var SyncNull = null;
var Stream = null;
var NameServer = null;
var Sync = null;
var SyncSemThread = null;

/*
 * ======== module$use ========
 */
function module$use()
{
    Stream = this;
    Memory = xdc.useModule('xdc.runtime.Memory');
    List = xdc.useModule('ti.sdo.utils.List');
    DriverTypes = xdc.useModule('ti.sdo.io.DriverTypes');
    DriverTable = xdc.useModule('ti.sdo.io.DriverTable');
    DriverAdapter = xdc.useModule('ti.sdo.io.converters.DriverAdapter');
    NameServer = xdc.useModule("ti.sdo.utils.NameServer");
    SyncSemThread = xdc.useModule("xdc.runtime.knl.SyncSemThread");
    Sync = xdc.useModule("xdc.runtime.knl.Sync");
}

/*
 * ======== module$static$init ========
 */
function module$static$init(mod, params)
{
    var nameSrvPrms = new NameServer.Params();
    nameSrvPrms.maxRuntimeEntries = params.maxRuntimeEntries;
    nameSrvPrms.tableSection = params.tableSection;
    
    mod.convTable = NameServer.create("Stream:ConverterTable", nameSrvPrms);
    
    for (var i=0; i < this.staticEntries.length; i++)
    {
       var entry = this.staticEntries[i];
       mod.convTable.addUInt32Meta(entry.name, entry.handle);
    }
}

/*
 *  ======== addMeta ========
 */
function addMeta(name, handle)
{
    Stream = this;
    
    var entry = new Stream.Entry();
    entry.name = name;
    entry.handle = handle;
    this.staticEntries.$add(entry);
}

/*
 * ======== instance$static$init ========
 */
function instance$static$init(obj, name, mode, params)
{
    obj.name = name;
    obj.chanParams = params.chanParams;
    obj.drvAdapHdl = false;
    obj.maxIssues = params.maxIssues;
    obj.issued = 0;
    obj.ready = 0;
    obj.mode = mode;
    obj.packetHeap = params.packetHeap;

    if (!params.sync) {
        obj.complete = SyncSemThread.create();
        obj.userSync = false; 
    }
    else {
        obj.complete = params.sync;
        obj.userSync = true;
    }

    obj.convHandle = null;
    
    List.construct(obj.freeList);
    
    obj.packets.length = params.maxIssues;

    Memory.staticPlace(obj.packets, 0, params.packetSection);
}

/*
 *  ======== viewInitBasic ========
 *  Initialize the 'Basic' Stream instance view.
 */
function viewInitBasic(view, obj)
{    
    var DriverTypes = xdc.useModule('ti.sdo.io.DriverTypes');
    var Stream = xdc.useModule('ti.sdo.io.Stream');
    var Program = xdc.useModule('xdc.rov.Program');
       
    view.label = Program.getShortName(obj.$label);
    view.maxIssues = obj.maxIssues;
    view.issued = obj.issued;
    view.ready = obj.ready;

    if (obj.mode == DriverTypes.INPUT) {
        view.mode = "INPUT";
    }
    else {
        view.mode = "OUTPUT";
    }

    view.userSuppliedSync = obj.userSync;
}

/*
 *  @(#) ti.sdo.io; 1, 0, 0, 0,301; 4-9-2010 18:37:35; /db/vtree/library/trees/ipc/ipc-d23x/src/
 */

