/* 
 * Copyright (c) 2010
 * Texas Instruments
 *
 *  All rights reserved.  Property of Texas Instruments
 *  Restricted rights to use, duplicate or disclose this code are
 *  granted through contract.
 * 
 * */
/*
 *  ======== DriverAdapter.xdc ========
 *
 */

import xdc.rov.ViewInfo;

import xdc.runtime.Error;
import xdc.runtime.Assert;
import ti.sdo.io.IConverter;
import ti.sdo.io.DriverTypes;
import ti.sdo.utils.List;

/*!
 *  ======== DriverAdapter ========
 *  @_nodoc
 *  Maps IDriver to IConverter. Stream uses this module if the IO stack
 *  has a terminating IDriver. A instance of this module handles an IDriver
 *  channel.
 */

module DriverAdapter inherits IConverter
{
    /*! 
     *  Error raised when IDriver_open failed
     */
    config Error.Id E_openFail  = {
        msg: "E_openFail: Driver failed to open channel"
    };

    /*!
     *  Assert when DriverAdapter.reclaim() called but no packet is ready
     */
    config Assert.Id A_noReadyPacket  = {
        msg: "A_noReadyPacket:  No packet ready for reclaim"
    };
    
    metaonly struct BasicView {
        String              label;
        String              driverName;
        Ptr                 driverHandle;
        Ptr                 channelHandle;
        UArg                channelParams;
        String              mode;
        String              callbackFxn[];
        UArg                callbackArg;
        String              readyForReclaim[];
    }
    
    @Facet
    metaonly config ViewInfo.Instance rovViewInfo = 
        ViewInfo.create({
            viewMap: [
                ['Basic', {type: ViewInfo.INSTANCE, viewInitFxn: 'viewInitBasic',
                   structName: 'BasicView'}],
            ]
        });
    
    /*!
     *  ======== callback ========
     *  @_nodoc
     *  driver callback function 
     *
     *  @param(cbArg)       callback argument 
     *  @param(*packet)     Pointer to the returned packet    
     */
    Void callback(UArg cbArg, DriverTypes.Packet *packet);
     
instance:
    
    /*! driver Handle got by calling {@link IDriver#create} */
    config Ptr driverHandle = 0;
    
internal:

    Int postInit(Object *obj, String name, Error.Block *eb);
    
    // -------- Internal Structures --------
    struct Instance_State {
        List.Object        fromDriver;    /* queue to collect pkts */
        String              name;
        Ptr                 driverHandle;  /* device handle */
        Ptr                 chan;          /* chan handle */
        UArg                chanParams;    /* chan params used for open */
        UInt                mode;          /* input or output */
        IConverter.DoneFxn  cbFxn;         /* callback into upper layer */
        UArg                cbArg;         /* callback arg */
    };
}
/*
 *  @(#) ti.sdo.io.converters; 1, 0, 0, 0,301; 4-9-2010 18:37:39; /db/vtree/library/trees/ipc/ipc-d23x/src/
 */

