/* 
 * Copyright (c) 2010
 * Texas Instruments
 *
 *  All rights reserved.  Property of Texas Instruments
 *  Restricted rights to use, duplicate or disclose this code are
 *  granted through contract.
 * 
 * */
/* ======== DriverAdapter.xs ========
 */

var List = null;
var DriverTypes = null;

/* ======== module$use ========
 */
function module$use()
{
    List = xdc.useModule("ti.sdo.utils.List");
    DriverTypes = xdc.useModule('ti.sdo.io.DriverTypes');
}


/* ======== instance$static$init ========
 */
function instance$static$init (obj, name, mode, chanParams, cbFxn, cbArg, params)
{
    List.construct(obj.fromDriver);
   
    obj.name = name;
    obj.driverHandle = params.driverHandle;
    obj.chan = null;
    obj.chanParams = chanParams;
    obj.mode = mode;
    obj.cbFxn = cbFxn;
    obj.cbArg = cbArg;
}
 
/*
 *  ======== viewInitBasic ========
 *  Initialize the 'Basic' DriverAdapter instance view.
 */
function viewInitBasic(view, obj)
{    
    var DriverAdapter = xdc.useModule('ti.sdo.io.converters.DriverAdapter');
    var DriverTypes = xdc.useModule('ti.sdo.io.DriverTypes');
    var Program = xdc.useModule('xdc.rov.Program');
       
    view.label = Program.getShortName(obj.$label);

    if (obj.name != 0x0) {
        try {
            view.driverName = Program.fetchString(obj.name);
        }
        catch (e) {
            view.$status["driverName"] = "Error: Problem getting driverName " +
                e.toString();
            return;
        }
    }

    view.driverHandle = obj.driverHandle;
    view.channelHandle = obj.chan;
    view.channelParams = Program.lookupDataSymbol(Number(obj.chanParams));
    //view.channelParams = "0x" + obj.chanParams.toString(16);
    
    if (obj.mode == DriverTypes.INPUT) {
        view.mode = "INPUT";
    }
    else {
        view.mode = "OUTPUT";
    }

    view.callbackFxn = Program.lookupFuncName(Number(obj.cbFxn));
    view.callbackArg = obj.cbArg;

    try {
        var readyQView = Program.scanObjectView('ti.sdo.utils.List', 
            obj.fromDriver, 'Basic');
    }
    catch (e) {
        view.$status["readyForReclaim"] = "Error: Problem scanning queue: " + 
            e.toString();
        return;
    }
    
    readyQView.label = (view.label + ".readyForReclaimQ");
    
    print("ready to fetch packets");
    
    for (var i=0; i<readyQView.elems.length; i++) {

        /* Get the element address from the List view. */
        var elemAddr = readyQView.elems[i];
        

        /* Enable after fix for encoded types */
        try {
            var packet = Program.fetchStruct(DriverTypes.Packet$fetchDesc, 
                elemAddr);
        }
        catch (e) {
            view.$status["readyForReclaim"] = "Error: fetching packet 0x" + 
                Number(elemAddr).toString(16) + ": " + e.toString();
            return;
        }
        
        print("ready to decode error");
        print("cmd " + packet.cmd);
        print("error " + packet.error);
        
        var packetStr = "Buffer:" + String(packet.addr);

        var cmd = Program.lookupDataSymbol(packet.cmd);

        if (cmd.length) {
            packetStr += " cmd:" + cmd[0];
        }
        //else {
            //view.$status["readyForReclaim"] = "Error: decoding PacketCmd " + 
            //  "0x" + Number(packet.cmd).toString(16);
            //return;
        //}        
                
        if (packet.error != 0) {
            var error = Program.lookupDataSymbol(packet.error);
            if (error.length) {
                packetStr += " error:" + error[0]; 
            }
            //else {
            //   view.$status["readyForReclaim"] = "Error: decoding Error.Id " + 
            //      Number(packet.error).toString(16);
            //    return;
            //}
        }
             
        view.readyForReclaim.$add(packetStr);
    }

}
/*
 *  @(#) ti.sdo.io.converters; 1, 0, 0, 0,301; 4-9-2010 18:37:39; /db/vtree/library/trees/ipc/ipc-d23x/src/
 */

