/* 
 * Copyright (c) 2010
 * Texas Instruments
 *
 *  All rights reserved.  Property of Texas Instruments
 *  Restricted rights to use, duplicate or disclose this code are
 *  granted through contract.
 * 
 * */
/*
 *  ======== NullConverter.c ========
 */

#include <xdc/std.h>

#include <xdc/runtime/Error.h>
#include <ti/sdo/utils/List.h>
#include <ti/sdo/io/IConverter.h>
#include <ti/sdo/io/IDriver.h>
#include <ti/sdo/io/DriverTypes.h>

#include "package/internal/NullConverter.xdc.h"

/*
 *************************************************************************
 *                       Instance functions
 *************************************************************************
 */

/*
 *  ======== NullConverter_Instance_init ========
 */
Void NullConverter_Instance_init(NullConverter_Object *obj, 
    const NullConverter_Params *params)
{
    List_Handle packetList;

    packetList = NullConverter_Instance_State_packetList(obj);

    List_construct(List_struct(packetList), NULL);
}

/*
 *  ======== NullConverter_open ========
 */
Void NullConverter_open(NullConverter_Object *obj, String name, UInt mode, 
    UArg chanParams, IConverter_DoneFxn cbFxn, UArg cbArg, Error_Block *eb)
{
    obj->mode = mode;
    obj->cbFxn = cbFxn;
    obj->cbArg = cbArg;
}
    
/*
 *  ======== NullConverter_close ========
 */
Void NullConverter_close(NullConverter_Object *obj, Error_Block *eb)
{
    obj->cbFxn = NULL;
    obj->cbArg = NULL;
}
    
/*
 *  ======== NullConverter_control ========
 */
Void NullConverter_control(NullConverter_Object *obj, 
    DriverTypes_ControlCmd cmd, UArg cmdArgs, Error_Block *eb)
{
    return;
}

/*
 *  ======== NullConverter_issue ========
 */
Void NullConverter_issue(NullConverter_Object *obj, DriverTypes_Packet *packet, 
    Error_Block *eb)
{
    List_put(NullConverter_Instance_State_packetList(obj), 
                (List_Elem *)packet);
    obj->cbFxn(obj->cbArg);
}

/*
 *  ======== NullConverter_reclaim ========
 */
Void NullConverter_reclaim(NullConverter_Object *obj, 
    DriverTypes_Packet **packet, Error_Block *eb)
{
    *packet = List_get(NullConverter_Instance_State_packetList(obj));
}

/*
 *  ======== NullConverter_query ========
 */
Bool NullConverter_query(NullConverter_Object *obj, Int qual)
{    
    return (TRUE);
}
/*
 *  @(#) ti.sdo.io.converters; 1, 0, 0, 0,301; 4-9-2010 18:37:39; /db/vtree/library/trees/ipc/ipc-d23x/src/
 */

