/* 
 * Copyright (c) 2010
 * Texas Instruments
 *
 *  All rights reserved.  Property of Texas Instruments
 *  Restricted rights to use, duplicate or disclose this code are
 *  granted through contract.
 * 
 * */
/*
 *  ======== Generator.xs ========
 *
 */
 
var Generator = null;
var List = null;
var IDriver = null;
var DriverTypes = null;

/*
 *  ======== module$use ========
 */
function module$use()
{
    Generator = this;
    List = xdc.useModule("ti.sdo.utils.List");
    IDriver = xdc.module("ti.sdo.io.IDriver");
    DriverTypes = xdc.useModule("ti.sdo.io.DriverTypes");
}

/*
 *  ======== module$static$init ========
 */
function module$static$init(mod, params)
{
    List.construct(mod.chanList);
}

/*
 *  ======== instance$static$init ========
 */
function instance$static$init(obj, params)
{
    for (var j=0; j<Generator.NUMCHANS; j++) {
        var chan = obj.chans[j];

        List.elemClearMeta(chan.elem);
        chan.inUse = false;
        chan.pendList = List.create();
        chan.cbFxn = null;
        chan.cbArg = null;
        chan.userFxn = null;
        chan.userArg = null;
        chan.returnPending = false;
    }
}

/*
 *  ======== viewInitBasic ========
 *  ROV code
 */
function viewInitBasic(view, obj)
{
    view.label = Program.getShortName(obj.$label);
}

function viewInitData(view, obj)
{
    var Program = xdc.useModule('xdc.rov.Program');
    var Generator = xdc.useModule('ti.sdo.io.drivers.Generator');
    
    /* Fetch the array of log entries. */
    print("Fetching chans at 0x"
        + Number(obj.chans.$addr).toString(16));
    try {
        var entries = Program.fetchArray(Generator.ChanObj$fetchDesc,
            obj.chans, Generator.NUMCHANS);
    }
    catch (e) {
        print("Caught exception while fetching Generator chans: "
            + e.toString());
        // TODO: Add error reporting
        throw (e);
    }
    
    view.label = "Channel Objects";
    for (var i = 0; i < Generator.NUMCHANS; i++) {      
        var chan = new Generator.Data_Element_View();
        if (i == 0 ) {
            chan.mode = "INPUT";
        }
        else {
            chan.mode = "OUTPUT";
        }
        chan.inUse = entries[i].inUse;
        chan.returnPending = entries[i].returnPending;
        chan.callbackFxn = Program.lookupAddr(Number(entries[i].cbFxn));
        chan.callbackArg = String(entries[i].cbArg);
        chan.userFxn = Program.lookupAddr(Number(entries[i].userFxn));
        chan.userArg = String(entries[i].userArg);        
        view.elements.$add(chan);
    }
    
    return (view);
}
/*
 *  @(#) ti.sdo.io.drivers; 1, 0, 0, 0,299; 4-9-2010 18:37:46; /db/vtree/library/trees/ipc/ipc-d23x/src/
 */

