/* 
 * Copyright (c) 2010
 * Texas Instruments
 *
 *  All rights reserved.  Property of Texas Instruments
 *  Restricted rights to use, duplicate or disclose this code are
 *  granted through contract.
 * 
 * */
/*
 *  ======== IomAdapter.xdc ========
 *
 *
 *  Open Issues:
 *  1. static policy not supported.
 *  2. Need to map errors, commands.
 *  3. Uarg vs Ptr
 */

import xdc.runtime.Error;
import ti.sdo.io.DriverTypes;

/*!
 * Module through which legacy iom drivers can plug into BIOS 6.x
 *
 * The IomAdapter module maps iom.h to IDriver.xdc. A legacy iom
 * driver has to hook into BIOS 6.x using this module. This module
 * handles ALL legacy drivers in the system. This single module
 * takes care of several legacy driver modules. 
 * 
 * As part of its create the IomAdapter module will call mbBindDev for
 * each of the legacy drivers. {@link #open} will call mdCreateChan. 
 * {@link #close} will call mdDeleteChan. {@link #submit} will call
 * mdSubmitChan. {@link #control} will call mdControlChan. A delete call will
 * call mdUnbindDev.
 *
 */
@ModuleStartup
@InstanceFinalize

module IomAdapter inherits ti.sdo.io.IDriver {      

    /*! Iom init function type definition. */
    typedef Void (*InitFunc)();

instance:

    /*! Pointer to legacy iom function table */
    config Ptr iomFxns = null;

    /*! Legacy iom init function */
    config InitFunc initFxn = null;

    /*! Legacy deviceParams */
    config Ptr deviceParams = null;
    
    /*! deviceId for iom driver */
    config UInt deviceId = 0;
    
    /*!
     *  ======== create ========
     *  Create an IomAdapter instance
     */
    create();
    
internal:

    Void driverCallback(Ptr cbArg, DriverTypes.Packet *packet);

    Void postInit(Object *obj);
    
    Error.Id mapStatus(Int status);

    struct ChanObj {
        Ptr                    iomChanHdl;
        DriverTypes.DoneFxn    cbFxn;
        UArg                   cbArg;
        DriverTypes.Packet     abortPkt;
    };

    struct Instance_State {
        Int            deviceId;
        Ptr            deviceParams;
        Ptr            deviceHandle;
        Ptr            iomFxns;
        InitFunc       initFxn;
    };
}
/*
 *  @(#) ti.sdo.io.drivers; 1, 0, 0, 0,299; 4-9-2010 18:37:46; /db/vtree/library/trees/ipc/ipc-d23x/src/
 */

