/* 
 * Copyright (c) 2010
 * Texas Instruments
 *
 *  All rights reserved.  Property of Texas Instruments
 *  Restricted rights to use, duplicate or disclose this code are
 *  granted through contract.
 * 
 * */
/* THIS FILE WAS GENERATED BY ti.sysbios.genx */

/*
 *  ======== stream.c ========
 */
 
#include <xdc/std.h>
#include <xdc/runtime/System.h>

#include <ti/sysbios/BIOS.h>
#include <ti/sysbios/knl/Task.h>

#include <ti/sdo/io/Stream.h>
#include <ti/sdo/io/drivers/Generator.h>

#include <xdc/cfg/global.h>

#define BUFSIZE 16
#define NBUFS   5

Void genSine(Ptr bufp, size_t nmaus, UArg arg);
Void myPrintf(Ptr bufp, size_t nmaus, UArg arg);

Int buf[BUFSIZE];
Ptr pbuf = &buf;

Stream_Handle handleIn, handleOut;
Int count = 1;

Generator_ChanParams genParamsIn = { genSine, NULL, FALSE };
Generator_ChanParams genParamsOut = { myPrintf, NULL, FALSE };

/* 
 * ======== genSine ========
 * Function used to simulate input channel
 * This function generates a sine wave.
 */
Void genSine(Ptr bufp, size_t nmaus, UArg arg)
{
    Int i; 
    Int *dst = (Int *)bufp;
    static Int data[16] = {
        0,  11793,  22594,  29956,  32767,  29956,  22594,  11793,
        0, -11793, -22594, -29956, -32767, -29956, -22594, -11793
    };

    for (i = 0; i < nmaus / sizeof(Int); i++) {
        dst[i] = data[i & 0xf];
    }
}

/* 
 * ======== myPrintf ========
 * Function used to simulate output channel
 * This function prints the buffer.
 */
Void myPrintf(Ptr bufp, size_t nmaus, UArg arg)
{
    Int i;
    Int *src = (Int *)bufp;

    for (i = 0; i < (nmaus / sizeof(Int)); i++) {
        System_printf("%d\n", src[i]);  
    }
}

/*
 *  ======== main ========
 */
Int main(Int argc, Char* argv[])
{
    Stream_Params streamParams;

    Stream_Params_init(&streamParams);

    System_printf("Creating streams in main\n", count);

    streamParams.chanParams = (UArg)&genParamsIn;
    handleIn = Stream_create("/genDevice", Stream_INPUT, &streamParams, NULL);

    streamParams.chanParams = (UArg)&genParamsOut;
    handleOut = Stream_create("/genDevice", Stream_OUTPUT, &streamParams, NULL);

    BIOS_start();

    return(0);
}

/*
 *  ======== tsk0Fxn ========
 *  Task that owns input channel
 */
Void task0Fxn (UArg arg1, UArg arg2)
{
    for (;;) {
        /* buf gets filled with sine data */
        Stream_issue(handleIn, pbuf, BUFSIZE, NULL, NULL);
        Stream_reclaim(handleIn, &pbuf, BIOS_WAIT_FOREVER, NULL, NULL);

        System_printf("Printing sine data %dth time\n", count);

        /* buf filled with sine data is printed out */
        Stream_issue(handleOut, pbuf, BUFSIZE, NULL, NULL);    
        Stream_reclaim(handleOut, &pbuf, BIOS_WAIT_FOREVER, NULL, NULL);        
        
        count++;

        if (count > NBUFS) {
            System_printf("End of stream example\n");
            System_exit(0);
        }
    }
}

/*
 *  @(#) ti.sdo.io.examples; 1, 0, 0, 0,107; 4-9-2010 18:39:48; /db/vtree/library/trees/ipc/ipc-d23x/src/
 */

