/* 
 * Copyright (c) 2010
 * Texas Instruments
 *
 *  All rights reserved.  Property of Texas Instruments
 *  Restricted rights to use, duplicate or disclose this code are
 *  granted through contract.
 * 
 * */
/*
 *  ======== Ipc.xs ========
 *
 */

var Ipc                    = null;
var Notify                 = null;
var SharedRegion           = null;
var MessageQ               = null;
var MultiProc              = null;
var NameServer             = null;
var NameServerRemoteNotify = null;
var Settings               = null;

var initEntryDone = false;

/*
 *  ======== module$meta$init ========
 */
function module$meta$init()
{
    /* Only process during "cfg" phase */
    if (xdc.om.$name != "cfg") {
        return;
    }

    Ipc = this;
    
    Ipc.entry.length = 0;

    Settings = xdc.module("ti.sdo.ipc.family.Settings");

    /* determine if slave data is needed to be generated for host */
    Ipc.generateSlaveDataForHost = Settings.generateSlaveDataForHost();

    /* Set Ipc.sr0MemorySetup based on device defaults */
    var sr0MemorySetup = Settings.getIpcSR0Setup();
    if (sr0MemorySetup) {
        Ipc.sr0MemorySetup = true;
    }
    else {
        Ipc.sr0MemorySetup = false;
    }

    /* get the host processor id */
    Ipc.hostProcId = Settings.getHostProcId();
}
 
/*
 *  ======== module$use ========
 */
function module$use()
{
    SharedRegion    = xdc.useModule("ti.sdo.ipc.SharedRegion"); 
    Cache           = xdc.useModule("ti.sysbios.hal.Cache");
    Notify          = xdc.useModule("ti.sdo.ipc.Notify");
    MessageQ        = xdc.useModule("ti.sdo.ipc.MessageQ");
    NameServerRemoteNotify = xdc.useModule("ti.sdo.ipc.NameServerRemoteNotify");
    MultiProc       = xdc.useModule("ti.sdo.utils.MultiProc");
    NameServer      = xdc.useModule("ti.sdo.utils.NameServer");
    Settings        = xdc.useModule("ti.sdo.ipc.family.Settings");
}
 
/*
 *  ======== module$static$init ========
 *  Initialize module values.
 */
function module$static$init(mod, params)
{
    /* this array will be setup below with internal array */
    mod.procEntry.length = MultiProc.numProcessors;

    /* set user's default attach/detach funtions */
    if (Ipc.userFxn.attach == undefined) {
        Ipc.userFxn.attach = null;
    }

    if (Ipc.userFxn.detach == undefined) {
        Ipc.userFxn.detach = null;
    }

    /* init Ipc.entry */
    initEntryArray();

    /* init the module state */
    for (var i=0; i < MultiProc.numProcessors; i++) {
        mod.procEntry[i].entry.remoteProcId  = i;
        mod.procEntry[i].entry.setupNotify   = true;
        mod.procEntry[i].entry.setupMessageQ = true;
        mod.procEntry[i].localConfigList     = null;
        mod.procEntry[i].remoteConfigList    = null;
        mod.procEntry[i].userObj             = null;
        mod.procEntry[i].slave               = false;
    }

    /* set module state with configured params */
    for (var i = 0; i < MultiProc.numProcessors; i++) {
        mod.procEntry[i].entry = Ipc.entry[i];
    }

    mod.ipcSharedAddr = null;
    mod.gateMPSharedAddr = null;
}

/*
 *  ======== setEntryMeta ========
 *  MultiProc.numProcessors must be set before calling this function
 */
function setEntryMeta(entry)
{
    var MultiProc = xdc.module("ti.sdo.utils.MultiProc");

    if (entry.remoteProcId == undefined) {
        Ipc.$logError("Ipc.setEntryMeta: remoteProcId was not specified.\n",
                      Ipc);
    }

    /* Log an error if the specified remoteProcId is invalid */
    if (entry.remoteProcId > MultiProc.numProcessors) {
        Ipc.$logError("Ipc.setEntryMeta: Invalid remoteProcId was " +
                      "specified.\n", Ipc);
    }

    /* init Ipc.entry */
    initEntryArray();

    if (entry.setupNotify != undefined) {
        Ipc.entry[entry.remoteProcId].setupNotify = entry.setupNotify;
    }

    if (entry.setupMessageQ != undefined) {
        Ipc.entry[entry.remoteProcId].setupMessageQ = entry.setupMessageQ;
    }
}

/*
 *  ======== initEntryArray ========
 *  This is an internal function. This function is called from
 *  setEntryMeta and module$static$init
 */
function initEntryArray()
{
    var MultiProc = xdc.module("ti.sdo.utils.MultiProc");

    /* init Ipc.entry if its not already initialized */
    if (!(initEntryDone)) {
        Ipc.entry.length = MultiProc.numProcessors;

        for (var i=0; i < MultiProc.numProcessors; i++) {
            Ipc.entry[i].remoteProcId     = i;
            Ipc.entry[i].setupNotify      = true;
            Ipc.entry[i].setupMessageQ    = true;
        }

        initEntryDone = true;
    }
}

/*
 *  ======== getObjTypeStr$view ========
 */
function getObjTypeStr$view(type)
{
    var typeStr;
    
    switch(type) {
        case this.ObjType_CREATESTATIC:
            typeStr = "CREATESTATIC";
            break;
        case this.ObjType_CREATESTATIC_REGION:
            typeStr = "CREATESTATIC";
            break;
        case this.ObjType_CREATEDYNAMIC:
            typeStr = "CREATEDYNAMIC";
            break;
        case this.ObjType_CREATEDYNAMIC_REGION:
            typeStr = "CREATEDYNAMIC_REGION";
            break;
        case this.ObjType_OPENDYNAMIC:
            typeStr = "OPENDYNAMIC";
            break;
        case this.ObjType_LOCAL:
            typeStr = "LOCAL";
            break;
        default:
            typeStr = null;
    }
    
    return (typeStr);
}
/*
 *  @(#) ti.sdo.ipc; 1, 0, 0, 0,398; 4-9-2010 18:37:48; /db/vtree/library/trees/ipc/ipc-d23x/src/
 */

