/* 
 * Copyright (c) 2010
 * Texas Instruments
 *
 *  All rights reserved.  Property of Texas Instruments
 *  Restricted rights to use, duplicate or disclose this code are
 *  granted through contract.
 * 
 * */
/*
 *  ======== message_dsp.c ========
 */

#include <xdc/std.h>
#include <string.h>

/*  -----------------------------------XDC.RUNTIME module Headers    */
#include <xdc/runtime/System.h>
#include <xdc/runtime/IHeap.h>

/*  ----------------------------------- IPC module Headers           */
#include <ti/ipc/Ipc.h>
#include <ti/ipc/MessageQ.h>
#include <ti/ipc/HeapBufMP.h>
#include <ti/ipc/MultiProc.h>

/*  ----------------------------------- BIOS6 module Headers         */
#include <ti/sysbios/BIOS.h>

/*  ----------------------------------- To get globals from .cfg Header */
#include <xdc/cfg/global.h>

#define ARM_MESSAGEQNAME "ARM"
#define DSP_MESSAGEQNAME "DSP"
#define HEAP_NAME        "myHeapBuf"
#define HEAP_ALIGN       128
#define HEAP_MSGSIZE     128
#define HEAP_NUMMSGS     4
#define HEAPID           0
#define NUMLOOPS         10

/*
 *  ======== tsk1_func ========
 *  A local message queue is created and a remote message queue is opened.
 *  Messages are sent to the remote message queue and retrieved from the
 *  local MessageQ.
 */
Void tsk1_func(UArg arg0, UArg arg1)
{
    MessageQ_Msg     msg;    
    MessageQ_Handle  messageQ;
    MessageQ_QueueId remoteQueueId;
    HeapBufMP_Handle heapHandle;
    Int              status;
    UInt16           msgId;

    /* Open the heap created by the other processor. Loop until opened. */
    do {
        status = HeapBufMP_open(HEAP_NAME, &heapHandle);
    } while (status < 0);

    /* Register this heap with MessageQ */
    MessageQ_registerHeap((IHeap_Handle)heapHandle, HEAPID);

    /* Create a local message queue */
    messageQ = MessageQ_create(DSP_MESSAGEQNAME, NULL);
    if (messageQ == NULL) {
        System_abort("MessageQ_create failed\n" );
    }    
    
    /* Open the remote message queue. Spin until it is ready. */
    do {
        status = MessageQ_open(ARM_MESSAGEQNAME, &remoteQueueId);
    } while (status < 0);

    /* Wait for a message from core0 and send it back to core0 */
    System_printf("Start the main loop\n");
    while (TRUE) {
        /* Get a message */
        status = MessageQ_get(messageQ, &msg, MessageQ_FOREVER);
        if (status < 0) {
           System_abort("This should not happen since timeout is forever\n");
        }

        System_printf("Sending a message #%d to arm\n", MessageQ_getMsgId(msg));

        /* Get the message id */
        msgId = MessageQ_getMsgId(msg);

        /* send the message to the remote processor */
        status = MessageQ_put(remoteQueueId, msg);
        if (status < 0) {
           System_abort("MessageQ_put had a failure/error\n");
        }
        
        /* test done */
        if (msgId >= NUMLOOPS) {
            break;
        }
    }

    System_printf("The test is complete\n");
    System_exit(0);
}

/*
 *  ======== main ========
 *  Synchronizes all processors.
 */
Int main(Int argc, Char* argv[])
{
    /*  
     *  Ipc_start() calls Ipc_attach() to synchronize all remote processors
     *  because 'Ipc.procSync' is set to 'Ipc.ProcSync_ALL' in *.cfg
     */
    Ipc_start();

    BIOS_start();
    return (0);
}
/*
 *  @(#) ti.sdo.ipc.examples.multicore.evmOMAPL138; 1, 0, 0, 0,31; 4-9-2010 18:39:04; /db/vtree/library/trees/ipc/ipc-d23x/src/
 */

