/* 
 * Copyright (c) 2010
 * Texas Instruments
 *
 *  All rights reserved.  Property of Texas Instruments
 *  Restricted rights to use, duplicate or disclose this code are
 *  granted through contract.
 * 
 * */
/* 
 *  The SysStd System provider is a good one to use for debugging 
 *  but does not have the best performance. Use xdc.runtime.SysMin
 *  for better performance.
 */
var System      = xdc.useModule('xdc.runtime.System');
var SysStd      = xdc.useModule('xdc.runtime.SysStd');
System.SupportProxy = SysStd;

/* Modules explicitly used in the application */
var Notify      = xdc.useModule('ti.sdo.ipc.Notify');
var Ipc         = xdc.useModule('ti.sdo.ipc.Ipc');
var BIOS        = xdc.useModule('ti.sysbios.BIOS');
var MultiProc   = xdc.useModule('ti.sdo.utils.MultiProc');

/* Task that does the notify sending */
var Task = xdc.useModule('ti.sysbios.knl.Task');
Program.global.tsk1 = Task.create('&tsk1_func');
Program.global.tsk1.instance.name = "tsk1";

/* Create a semaphore with count 0 */
var Semaphore   = xdc.useModule('ti.sysbios.ipc.Semaphore');
Program.global.semHandle = Semaphore.create(0);

/* To avoid wasting shared memory for MessageQ transports */
for (var i=0; i < MultiProc.numProcessors; i++) {
    Ipc.setEntryMeta({
        remoteProcId: i,
        setupMessageQ: false,
    });
}

/* Synchronize all processors (this will be done in Ipc_start) */
Ipc.procSync = Ipc.ProcSync_ALL;

/* 
 * Configure NotifySetup for da830 to use the 2nd interrupt line
 * This is required for the Notify example
 */
var NotifySetup = xdc.useModule('ti.sdo.ipc.family.da830.NotifySetup');

/* This particular example takes advantage of 2 interrupt lines */
NotifySetup.useSecondLine = true;

/* Shared Memory Map */
var SHAREDMEM           = 0xC2000000;
var SHAREDMEMSIZE       = 0x00020000;

/* 
 *  Need to define the shared region. The IPC modules use this
 *  to make portable pointers. All processors need to add this
 *  call with their base address of the shared memory region.
 *  If the processor cannot access the memory, do not add it.
 */ 
var SharedRegion = xdc.useModule('ti.sdo.ipc.SharedRegion');
SharedRegion.setEntryMeta(0,
    { base: SHAREDMEM, 
      len:  SHAREDMEMSIZE,
      ownerProcId: 0,
      isValid: true,
      name: "shared_mem",
    });
/*
 *  @(#) ti.sdo.ipc.examples.multicore.evmOMAPL138; 1, 0, 0, 0,31; 4-9-2010 18:39:04; /db/vtree/library/trees/ipc/ipc-d23x/src/
 */

