/* 
 * Copyright (c) 2010
 * Texas Instruments
 *
 *  All rights reserved.  Property of Texas Instruments
 *  Restricted rights to use, duplicate or disclose this code are
 *  granted through contract.
 * 
 * */
/*
 *  ======== Settings.xs ========
 *
 */

/*
 *  ======== setDeviceAliases ========
 */
function setDeviceAliases(deviceTable, deviceAliases) 
{
    for (var device in deviceAliases) {
        for each (var alias in deviceAliases[device]) {
            if (deviceTable[alias] == null && deviceTable[device] != null) {
                deviceTable[alias] = deviceTable[device];
            }
        }
    }
}
 
/*
 *  ======== aliases ========
 *  Aliases for devices used in IPC
 */
var aliases = {
    'TMS320CTCI6498'    : ['TMS320CTCI6497'],
    'TMS320C6472'       : ['TMS320CTCI6486'],
    'TMS320C6474'       : ['TMS320CTCI6488'],
    'TMS320DA830'       : ['OMAPL138', 'OMAPL137'],
    'OMAP3530'          : ['TMS320C3430'],
}
 
/*
 *  ======== procNames ========
 */
var procNames = {
    'TMS320CDM6446'     : ["DSP", "HOST"],
    'TMS320DA830'       : ["DSP", "HOST"],
    'OMAPL138'          : ["DSP", "HOST"],
    'TMS320CDM740'      : ["DSP", "VIDEO", "DSS", "HOST"],
    'TMS320CTCI6498'    : ["CORE0", "CORE1", "CORE2", "CORE3"],
    'TMS320C6472'       : ["CORE0", "CORE1", "CORE2",
                           "CORE3", "CORE4", "CORE5"],    
    'TMS320C6474'       : ["CORE0", "CORE1", "CORE2"], 
    'OMAP3530'          : ["DSP", "HOST"],
    'Ducati'            : ["DSP", "CORE0", "CORE1", "HOST"], /* OMAP4430 */
    'Tesla'             : ["DSP", "CORE0", "CORE1", "HOST"], /* OMAP4430 */
};
setDeviceAliases(procNames, aliases);

/*
 *  ======== hostNeedsSlaveData =======
 */
var hostNeedsSlaveData = {
    'TMS320CDM740'      : 1,
    'OMAP3530'          : 1,
    'Ducati'            : 1, /* OMAP4430 */
    'Tesla'             : 1, /* OMAP4430 */
    'TMS320CDM6446'     : 1,
    'TMS320DA830'       : 1,
    'OMAPL138'          : 1,
};
setDeviceAliases(hostNeedsSlaveData, aliases);

/*
 *  ======== sr0MemorySetup =======
 *  The devices in this list means these devices have a slave mmu
 *  that needs to be configured by the host before the slave can proceed.
 */
var sr0MemorySetup = {
    'TMS320CDM740'      : 1,
    'OMAP3530'          : 1,
    'Ducati'            : 1, /* OMAP4430 */
    'Tesla'             : 1, /* OMAP4430 */
};
setDeviceAliases(sr0MemorySetup, aliases);

/*
 *  ======== hostProcNames =======
 *  The name of the host or master processor.
 */
var hostProcNames = {
    'TMS320CDM6446'     : ["HOST"],
    'TMS320DA830'       : ["HOST"],
    'OMAPL138'          : ["HOST"],
    'TMS320CDM740'      : ["HOST"],
    'OMAP3530'          : ["HOST"],
    'Ducati'            : ["HOST"], /* OMAP4430 */
    'Tesla'             : ["HOST"], /* OMAP4430 */
    'TMS320CTCI6498'    : ["CORE0"],
    'TMS320C6472'       : ["CORE0"],
    'TMS320C6474'       : ["CORE0"], 
};
setDeviceAliases(hostProcNames, aliases);

/*
 *  ======== notifySetupDelegates ========
 */
var notifySetupDelegates = {
    'OMAP3530'          : { del: 'ti.sdo.ipc.family.omap3530.NotifySetup', },
    'TMS320CDM6446'     : { del: 'ti.sdo.ipc.family.dm6446.NotifySetup', },
    'TMS320DA830'       : { del: 'ti.sdo.ipc.family.da830.NotifySetup', },
    'TMS320CDM740'      : { del: 'ti.sdo.ipc.family.dm740.NotifySetup', },
    'TMS320CTCI6498'    : { del: 'ti.sdo.ipc.family.c647x.NotifySetup', },  
    'TMS320C6472'       : { del: 'ti.sdo.ipc.family.c647x.NotifySetup', },  
    'TMS320C6474'       : { del: 'ti.sdo.ipc.family.c647x.NotifySetup', },
    'Ducati'            : { del: 'ti.sdo.ipc.family.omap4430.NotifySetup', },
    'Tesla'             : { del: 'ti.sdo.ipc.family.omap4430.NotifySetup', },
};
setDeviceAliases(notifySetupDelegates, aliases);

/*
 *  ======== messageQSetupDelegates ========
 */
var messageQSetupDelegates = {
    'OMAP3530'          : { del: 'ti.sdo.ipc.transports.TransportShmSetup', },
    'TMS320CDM6446'     : { del: 'ti.sdo.ipc.transports.TransportShmSetup', },
    'TMS320DA830'       : { del: 'ti.sdo.ipc.transports.TransportShmSetup', },
    'TMS320CDM740'      : { del: 'ti.sdo.ipc.transports.TransportShmSetup', },
    'TMS320CTCI6498'    : { del: 'ti.sdo.ipc.transports.TransportShmSetup', },  
    'TMS320C6472'       : { del: 'ti.sdo.ipc.transports.TransportShmSetup', },  
    'TMS320C6474'       : { del: 'ti.sdo.ipc.transports.TransportShmSetup', },
    'Ducati'            : { del: 'ti.sdo.ipc.transports.TransportShmSetup', },
    'Tesla'             : { del: 'ti.sdo.ipc.transports.TransportShmSetup', },
};
setDeviceAliases(messageQSetupDelegates, aliases);

/*
 *  ======== interruptDelegates ========
 */
var interruptDelegates = {
    'ti.catalog.arm.nda' : { /* OMAP4430 */
        'Ducati' : { del: 'ti.sdo.ipc.family.omap4430.InterruptDucati', },
    },
    'ti.catalog.arm' : {
        'TMS320CDM740'  : { del: 'ti.sdo.ipc.family.dm740.InterruptDucati', },
        'TMS320CDM6446' : { del: 'ti.sdo.ipc.family.dm6446.InterruptArm', },
        'TMS320DA830'   : { del: 'ti.sdo.ipc.family.da830.InterruptArm', },
        'OMAPL138'      : { del: 'ti.sdo.ipc.family.da830.InterruptArm', },
    },
    'ti.catalog.c6000' : {
        'OMAP3530'     : { del: 'ti.sdo.ipc.family.omap3530.InterruptDsp', },
        'TMS320CDM6446': { del: 'ti.sdo.ipc.family.dm6446.InterruptDsp', },
        'TMS320DA830'  : { del: 'ti.sdo.ipc.family.da830.InterruptDsp', },
        'OMAPL138'     : { del: 'ti.sdo.ipc.family.da830.InterruptDsp', },
        'TMS320CDM740' : { del: 'ti.sdo.ipc.family.dm740.InterruptDsp', },
        'TMS320C6472'  : { del: 'ti.sdo.ipc.family.c647x.Interrupt', },
        'TMS320C6474'  : { del: 'ti.sdo.ipc.family.c647x.Interrupt', },
        'TMS320CTCI6498':{ del: 'ti.sdo.ipc.family.c647x.Interrupt', },
    },
    'ti.catalog.c6000.nda' : { /* OMAP4430 */
        'Tesla'        : { del: 'ti.sdo.ipc.family.omap4430.InterruptDsp', },
    },
};
for (var family in interruptDelegates) {
    setDeviceAliases(interruptDelegates[family], aliases);
}

/*
 *  ======== spinlockDelegates ========
 */
var spinlockDelegates = {
    'ti.catalog.arm.nda' : {
        'Ducati' : {   /* OMAP4430 */
            baseAddr:   0x4A0F6800,
            numLocks:   32,
        },
    },
    'ti.catalog.arm' : {
        'TMS320CDM740' : {
            baseAddr:   0x480CA800,
            numLocks:   32,
        },
    },
    'ti.catalog.c6000' : {
        'TMS320CDM740' : {
            baseAddr:   0x080CA800,
            numLocks:   32,
        },
    },
    'ti.catalog.c6000.nda' : {
        'Tesla' : { /* OMAP4430 */
            baseAddr:   0x4A0F6800,
            numLocks:   32,
        },
    }
}
for (var family in spinlockDelegates) {
    setDeviceAliases(spinlockDelegates[family], aliases);
}


/*
 *  ======== hwSemDelegates ========
 */
var hwSemDelegates = {
    'ti.catalog.c6000' : {
        'TMS320C6474' : {
            baseAddr:   0x02B40100,
            queryAddr:  0x02B40300,
            numSems:    32,
        },
        'TMS320CTCI6498' : {
            baseAddr:   0x02640100,
            queryAddr:  0x02640200,
            numSems:    32,
        },
    },
}
for (var family in hwSemDelegates) {
    setDeviceAliases(hwSemDelegates[family], aliases);
}

/*
 *  ======== getGateHWSemSettings ========
 */
function getGateHWSemSettings()
{
    var errorString = "IPC does not have a default GateHWSem" +
                      " delegate for the " + deviceName + " device!";
    var catalogName = Program.cpu.catalogName;
    var deviceName = Program.cpu.deviceName;

    var errStr = "The device " + deviceName +
        " does not support hardware semaphores!";

    try { 
        var hwSemSettings = hwSemDelegates[catalogName][deviceName];
    }
    catch(e) {
        throw new Error(errStr);
    }
    
    if (hwSemSettings == null) {
        throw new Error(errStr);
    }
    
    return (hwSemSettings);
}

/*
 *  ======== getGateHWSpinlockSettings ========
 */
function getGateHWSpinlockSettings()
{
    var errorString = "IPC does not have a default GateHWSpinlock" +
                      " delegate for the " + deviceName + " device!";
    var catalogName = Program.cpu.catalogName;
    var deviceName = Program.cpu.deviceName;
    
    var errStr = "The device " + deviceName +
        " does not support hardware spinlocks!";

    try {
        var spinLockSettings = spinlockDelegates[catalogName][deviceName];
    }
    catch(e) {
        throw new Error(errStr);
    }
    
    if (spinLockSettings == null) {
        throw new Error(errStr);
    }
    
    return (spinLockSettings);
}

/*
 *  ======== generateSlaveDataForHost ========
 */
function generateSlaveDataForHost()
{
    var retval = hostNeedsSlaveData[Program.cpu.deviceName];
    
    if (retval != null) {
        return (true);
    }

    return (false);
}

/*
 *  ======== getHostProcId ========
 */
function getHostProcId()
{
    var MultiProc = xdc.module("ti.sdo.utils.MultiProc");

    var hostProcName = hostProcNames[Program.cpu.deviceName];
    
    if (hostProcName == null) {
        /* The device doesn't have a core that runs a hlos */
        return (MultiProc.INVALIDID);
    }
    
    /* 
     *  If the device may run a hlos, return the corresponding core's MultiProc
     *  id. MultiProc.INVALIDID will be returned if the core exists but isn't
     *  being used in the application
     */ 
    return(MultiProc.getIdMeta(String(hostProcName)));
}

/*
 *  ======== getIpcSR0Setup ========
 */
function getIpcSR0Setup()
{
    var memorySetup = sr0MemorySetup[Program.cpu.deviceName];
    
    if (memorySetup == null) {
        /* The device has memory available to it */
        return (true);
    }
    else {
        /* The device needs host to enable memory through mmu */
        return (false);
    }
}

/*
 *  ======== getHWGate ========
 */
function getHWGate()
{
    if (Program.cpu.deviceName == "TMS320C6472" ||
        Program.cpu.deviceName == "TMS320CTCI6486") {
        return ('ti.sdo.ipc.gates.GateAAMonitor');
    }

    try {
        this.getGateHWSpinlockSettings();
        return ('ti.sdo.ipc.gates.GateHWSpinlock');
    }
    catch(e) {
    }
    
    try {
        this.getGateHWSemSettings();
        return ('ti.sdo.ipc.gates.GateHWSem');
    }
    catch(e) {
    }

    return('ti.sdo.ipc.gates.GatePeterson');
}

/*
 *  ======== getDefaultInterruptDelegate ========
 */
function getDefaultInterruptDelegate()
{
    var catalogName = Program.cpu.catalogName;
    var deviceName = Program.cpu.deviceName;
 
    var delegate = interruptDelegates[catalogName][deviceName];
    
    if (delegate == null) {
        throw new Error ("IPC does not have a default Interrupt"
            + " delegate for the " + deviceName + " device!");
    }
    
    return (delegate.del);
}

/*
 *  ======== getNotifySetupDelegate ========
 */
function getNotifySetupDelegate() 
{
    var deviceName = Program.cpu.deviceName;
    
    var delegate = notifySetupDelegates[deviceName];
    
    if (delegate == null) {
        throw new Error ("IPC does not have a default NotifySetup"
            + " delegate for the " + deviceName + " device!");
    }
    
    return (delegate.del);
}

/*
 *  ======== getMessageQSetupDelegate ========
 */
function getMessageQSetupDelegate() 
{
    var deviceName = Program.cpu.deviceName;
    
    var delegate = messageQSetupDelegates[deviceName];
    
    if (delegate == null) {
        throw new Error ("IPC does not have a default MessageQ setup"
            + " delegate for the " + deviceName + " device!");
    }
    
    return (delegate.del);
}

/*
 *  ======== procInDevice ========
 */
function procInDevice(procName)
{
    if (procNames[Program.cpu.deviceName] == null) {
        this.$logError("The device (" + Program.cpu.deviceName + 
                       ") isn't supported by Notify", this);
    }
    
    /* Search through the procNames table */
    for each (name in procNames[Program.cpu.deviceName]) {
        if (name == procName) {
            return (true);
        }
    }
    
    return (false);
}

/*
 *  ======== getDeviceProcNames ========
 */
function getDeviceProcNames()
{
    if (procNames[Program.cpu.deviceName] == null) {
        this.$logError("The device (" + Program.cpu.deviceName + 
                       ") isn't supported by Notify", this);
    }

    return (procNames[Program.cpu.deviceName]);
}
/*
 *  @(#) ti.sdo.ipc.family; 1, 0, 0, 0,221; 4-9-2010 18:37:55; /db/vtree/library/trees/ipc/ipc-d23x/src/
 */

