/* 
 * Copyright (c) 2010
 * Texas Instruments
 *
 *  All rights reserved.  Property of Texas Instruments
 *  Restricted rights to use, duplicate or disclose this code are
 *  granted through contract.
 * 
 * */
/*
 *  ======== NotifySetup.c ========
 */
 
#include <xdc/std.h>
#include <ti/sdo/ipc/notifyDrivers/NotifyDriverShm.h>
#include <ti/sdo/ipc/_Notify.h>
#include <ti/sdo/utils/_MultiProc.h>

#include <xdc/runtime/Error.h>

#include "package/internal/NotifySetup.xdc.h"

/*!
 *  ======== NotifySetup_attach ========
 */     
Int NotifySetup_attach(UInt16 remoteProcId, Ptr sharedAddr)
{
    NotifyDriverShm_Params notifyShmParams;
    NotifyDriverShm_Handle shmDrvHandle;
    Notify_Handle notifyHandle;
    Error_Block eb;

    /* Initialize the error block */
    Error_init(&eb);
    
    /* init params and set default values */
    NotifyDriverShm_Params_init(&notifyShmParams);
    notifyShmParams.intVectorId     = NotifySetup_dspIntVectId;
    notifyShmParams.sharedAddr      = sharedAddr;
    notifyShmParams.remoteProcId  = remoteProcId;
        
    shmDrvHandle = NotifyDriverShm_create(&notifyShmParams, &eb);
    if (shmDrvHandle == NULL) {
        return (Notify_E_FAIL);
    }
    
    notifyHandle = Notify_create(NotifyDriverShm_Handle_upCast(shmDrvHandle), 
                                 remoteProcId, 0, NULL, &eb);
    if (notifyHandle == NULL) {
        NotifyDriverShm_delete(&shmDrvHandle); 
        
        return (Notify_E_FAIL);
    }

    return (Notify_S_SUCCESS);
}

/*!
 * ======== NotifySetup_sharedMemReq ========
 */
SizeT NotifySetup_sharedMemReq(UInt16 remoteProcId, Ptr sharedAddr)
{
    SizeT memReq;
    NotifyDriverShm_Params params;
    
    NotifyDriverShm_Params_init(&params);
    params.sharedAddr      = sharedAddr;
    params.intVectorId     = NotifySetup_dspIntVectId;
    params.remoteProcId    = remoteProcId;

    memReq = NotifyDriverShm_sharedMemReq(&params);
    
    return(memReq);
}

/*!
 * ======== NotifySetup_intLineAvailable ========
 */
Bool NotifySetup_intLineAvailable(UInt16 remoteProcId)
{
    return (TRUE);
}

/*
 */

/*
 *  @(#) ti.sdo.ipc.family.c647x; 1, 0, 0, 0,31; 4-9-2010 18:37:59; /db/vtree/library/trees/ipc/ipc-d23x/src/
 */

