/* 
 * Copyright (c) 2010
 * Texas Instruments
 *
 *  All rights reserved.  Property of Texas Instruments
 *  Restricted rights to use, duplicate or disclose this code are
 *  granted through contract.
 * 
 * */
/*
 *  ======== NotifySetup.xdc ========
 *
 */
 
import ti.sdo.utils.MultiProc;

/*!
 *  ======== NotifySetup ======== 
 *  Manages setup of the default Notify driver handles
 *
 *  Creates the default notify drivers for each pair of processors. 
 */
module NotifySetup inherits ti.sdo.ipc.interfaces.INotifySetup
{
    /*! Possible incoming interrupt IDs for DSP */
    enum DSP_INT {
        DSP_INT0 = 5,
        DSP_INT1 = 67
    }
    
    /*! Possible incoming interrupt IDs for ARM */
    enum ARM_INT {
        ARM_INT0 = 28,
        ARM_INT1 = 29
    }

    /*! 
     *  Incoming interrupt ID for line #0 line on DSP 
     *
     *  See {@link #DSP_INT} for possible values.
     */
    config UInt dspRecvIntId0 = DSP_INT0;
    
    /*! Vector ID to use on DSP for line #1 */    
    config UInt dspIntVectId0 = 5;
    
    /*! 
     *  Incoming interrupt ID for line #0 line on ARM 
     *
     *  See {@link #ARM_INT} for possible values.
     */
    config UInt armRecvIntId0 = ARM_INT0;
    
    /*! Enable the second interrupt line */
    config Bool useSecondLine = false;
    
    /*! 
     *  Incoming interrupt ID for line #1 line on DSP 
     *
     *  See {@link #DSP_INT} for possible values.
     */
    config UInt dspRecvIntId1 = DSP_INT1;
    
    /*! Vector ID to use on DSP for line #1 */
    config UInt dspIntVectId1 = 6;
    
    /*! 
     *  Incoming interrupt ID for line #1 line on ARM 
     *
     *  See {@link #ARM_INT} for possible values.
     */
    config UInt armRecvIntId1 = ARM_INT1;
    
internal:

}
/*
 *  @(#) ti.sdo.ipc.family.da830; 1, 0, 0, 0,98; 4-9-2010 18:38:00; /db/vtree/library/trees/ipc/ipc-d23x/src/
 */

