/* 
 * Copyright (c) 2010
 * Texas Instruments
 *
 *  All rights reserved.  Property of Texas Instruments
 *  Restricted rights to use, duplicate or disclose this code are
 *  granted through contract.
 * 
 * */
/*
 *  ======== NotifySetup.c ========
 */
#include <xdc/std.h>
#include <xdc/runtime/Error.h>

#include <ti/sdo/ipc/notifyDrivers/NotifyDriverShm.h>
#include <ti/sdo/ipc/_Notify.h>
#include <ti/sdo/ipc/Ipc.h>

#include <ti/sdo/utils/_MultiProc.h>

#include "package/internal/NotifySetup.xdc.h"

/*
 *************************************************************************
 *                      Module functions
 *************************************************************************
 */

/*!
 *  ======== NotifySetup_attach ========
 *  Initialize interrupt
 */     
Int NotifySetup_attach(UInt16 remoteProcId, Ptr sharedAddr)
{
    NotifyDriverShm_Params notifyShmParams;
    NotifyDriverShm_Handle shmDrvHandle;
    Notify_Handle notifyHandle;
    Int status = Notify_S_SUCCESS;
    Error_Block eb;
    
    Error_init(&eb);
    
    NotifyDriverShm_Params_init(&notifyShmParams);
    notifyShmParams.sharedAddr = sharedAddr;
    notifyShmParams.remoteProcId  = remoteProcId;
    
    /* Disable cache for inter-ducati NotifyDriverShm instances */
    if ((MultiProc_self() == NotifySetup_dssProcId && 
         remoteProcId == NotifySetup_videoProcId) ||
        (MultiProc_self() == NotifySetup_videoProcId && 
         remoteProcId == NotifySetup_dssProcId)) {
         notifyShmParams.cacheLineSize = 0;
         notifyShmParams.cacheEnabled = FALSE;
    }
        
    /* Set the intVectorId if on the DSP */
    if (MultiProc_self() == NotifySetup_dspProcId) {
        notifyShmParams.intVectorId = NotifySetup_dspIntVectId;
    }
        
    shmDrvHandle = NotifyDriverShm_create(&notifyShmParams, &eb);
    if (shmDrvHandle == NULL) {
        return (Notify_E_FAIL);
    }
    
    notifyHandle = Notify_create(NotifyDriverShm_Handle_upCast(shmDrvHandle), 
                                 remoteProcId, 0, NULL, &eb);

    if (notifyHandle == NULL) {
        NotifyDriverShm_delete(&shmDrvHandle);
        status = Notify_E_FAIL;
    }

    return (status);
}


/*!
 *  ======== NotifySetup_sharedMemReq ========
 */  
SizeT NotifySetup_sharedMemReq(UInt16 remoteProcId, Ptr sharedAddr) 
{
    SizeT memReq;
    NotifyDriverShm_Params notifyShmParams;
    
    NotifyDriverShm_Params_init(&notifyShmParams);
    notifyShmParams.sharedAddr = sharedAddr;
    /* Disable cache for inter-ducati NotifyDriverShm instances */
    if ((MultiProc_self() == NotifySetup_dssProcId && 
         remoteProcId == NotifySetup_videoProcId) ||
        (MultiProc_self() == NotifySetup_videoProcId && 
        remoteProcId == NotifySetup_dssProcId)) {
        notifyShmParams.cacheEnabled = FALSE;
        notifyShmParams.cacheLineSize = 0;
    }

    memReq = NotifyDriverShm_sharedMemReq(&notifyShmParams);

    return (memReq);
}

/*!
 * ======== NotifySetup_intLineAvailable ========
 */
Bool NotifySetup_intLineAvailable(UInt16 remoteProcId)
{
    return (TRUE);
}

/*
 */

/*
 *  @(#) ti.sdo.ipc.family.dm740; 1, 0, 0, 0,116; 4-9-2010 18:38:06; /db/vtree/library/trees/ipc/ipc-d23x/src/
 */

