/* 
 * Copyright (c) 2010
 * Texas Instruments
 *
 *  All rights reserved.  Property of Texas Instruments
 *  Restricted rights to use, duplicate or disclose this code are
 *  granted through contract.
 * 
 * */
/*
 *  ======== NotifySetup.c ========
 */
#include <xdc/std.h>
#include <xdc/runtime/Error.h>
#include <ti/sdo/ipc/notifyDrivers/NotifyDriverShm.h>
#include <ti/sdo/ipc/_Notify.h>
#include <ti/sdo/utils/_MultiProc.h>

#include "package/internal/NotifySetup.xdc.h"

/*
 *************************************************************************
 *                      Module functions
 *************************************************************************
 */

/*!
 *  ======== NotifySetup_attach ========
 *  Initialize interrupt
 */     
Int NotifySetup_attach(UInt16 remoteProcId, Ptr sharedAddr)
{
    NotifyDriverShm_Params notifyShmParams;
    NotifyDriverShm_Handle hostDriverHandle;
    Notify_Handle notifyHandle;
    Error_Block eb;
    Int status = Notify_S_SUCCESS;
    UInt hostProcId = 1 - MultiProc_self();

    Error_init(&eb);
    
    /*
     *  Setup the notify driver to the HOST
     */     
    NotifyDriverShm_Params_init(&notifyShmParams);
    notifyShmParams.remoteProcId   = hostProcId;
    notifyShmParams.sharedAddr     = sharedAddr;
    notifyShmParams.intVectorId    = NotifySetup_dspIntVectId;
    
    hostDriverHandle = NotifyDriverShm_create(&notifyShmParams, &eb);
    if (hostDriverHandle == NULL) {
        status = Notify_E_FAIL;
    }
    
    /* Register the Notify driver with the Notify module */
    notifyHandle = Notify_create(NotifyDriverShm_Handle_upCast(hostDriverHandle),
                  hostProcId,
                  0,        /* lineId */
                  NULL,     /* params */
                  &eb);

    if (notifyHandle == NULL) {
        NotifyDriverShm_delete(&hostDriverHandle);
        status = Notify_E_FAIL;
    }

    return (status);
}

/*!
 *  ======== NotifySetup_sharedMemReq ========
 */   
SizeT NotifySetup_sharedMemReq(UInt16 remoteProcId, Ptr sharedAddr) 
{
    SizeT memReq;
    NotifyDriverShm_Params params;
    
    NotifyDriverShm_Params_init(&params);
    params.sharedAddr = sharedAddr;
    
    memReq = NotifyDriverShm_sharedMemReq(&params);
    
    return(memReq);
}

/*!
 * ======== NotifySetup_intLineAvailable ========
 */
Bool NotifySetup_intLineAvailable(UInt16 remoteProcId)
{
    return (TRUE);
}

/*
 */
/*
 *  @(#) ti.sdo.ipc.family.omap3530; 1, 0, 0, 0,108; 4-9-2010 18:38:10; /db/vtree/library/trees/ipc/ipc-d23x/src/
 */

