/* 
 * Copyright (c) 2010
 * Texas Instruments
 *
 *  All rights reserved.  Property of Texas Instruments
 *  Restricted rights to use, duplicate or disclose this code are
 *  granted through contract.
 * 
 * */
/*
 *  ======== GateAAMonitor.xdc ========
 *
 */
 
package ti.sdo.ipc.gates;

import xdc.runtime.Error;
import xdc.runtime.Assert;
import xdc.runtime.IGateProvider;
import xdc.runtime.Diags;
import xdc.runtime.Log;

import ti.sdo.ipc.Ipc;

import ti.sdo.ipc.interfaces.IGateMPSupport;

/*!
 *  ======== GateAAMonitor ========
 *  Multiprocessor gate that utilizes an atomic access monitor (AAM)
 */
@InstanceInitError

module GateAAMonitor inherits IGateMPSupport
{
    /*! @_nodoc */
    metaonly struct BasicView {
        Ptr     sharedAddr;
        UInt    nested;
        String  enteredBy;     /* Entered or free */
    }

    /*!
     *  ======== rovViewInfo ========
     *  @_nodoc
     */
    @Facet
    metaonly config xdc.rov.ViewInfo.Instance rovViewInfo =
        xdc.rov.ViewInfo.create({
            viewMap: [
                ['Basic',
                    {
                        type: xdc.rov.ViewInfo.INSTANCE,
                        viewInitFxn: 'viewInitBasic',
                        structName: 'BasicView'
                    }
                ],
            ]
        });
        
    /*!
     *  ======== A_invSharedAddr ========
     *  Assert raised when supplied sharedAddr is invalid
     *
     *  C6472 requires that shared region 0 be placed in SL2 memory and that
     *  all GateMP instances be allocated from region 0.  The gate itself may
     *  be used to protect the contents of any shared region.
     */
    config Assert.Id A_invSharedAddr  = {
        msg: "A_invSharedAddr: Address must be in shared L2 address space"
    };
    
    /*!
     *  ======== numInstances ========
     *  Maximum number of instances supported by the GateAAMonitor module
     */
    config UInt numInstances = 32;

instance:


internal:

    /*! Get the lock */
    @DirectCall
    UInt getLock(Ptr sharedAddr);
    
    /*! Initialize monitor */
    Void postInit(Object *obj); 
    
    /*! L1D cache line size is 64 */
    const UInt CACHELINE_SIZE = 64;

    /*!
     *  Range of SL2 RAM on TMS320TCI6486. Used for ensuring sharedAddr is
     *  valid
     */
    const Ptr SL2_RANGE_BASE = 0x00200000;
    const Ptr SL2_RANGE_MAX  = 0x002bffff;
    
    struct Instance_State {
        volatile UInt32*    sharedAddr;
        UInt                nested;    /* For nesting */       
        IGateProvider.Handle localGate;
    };
}
/*
 *  @(#) ti.sdo.ipc.gates; 1, 0, 0, 0,142; 4-9-2010 18:38:19; /db/vtree/library/trees/ipc/ipc-d23x/src/
 */

