/* 
 * Copyright (c) 2010
 * Texas Instruments
 *
 *  All rights reserved.  Property of Texas Instruments
 *  Restricted rights to use, duplicate or disclose this code are
 *  granted through contract.
 * 
 * */
/*
 *  ======== GateAAMonitor.xs ========
 *
 */
 
var GateAAMonitor   = null;
var Cache           = null;
var Ipc             = null;
var GateMP          = null;

/*!
 *  ======== module$use ========
 */
function module$use()
{
    GateAAMonitor   = this;
    Cache           = xdc.useModule('ti.sysbios.hal.Cache');
    Ipc             = xdc.useModule('ti.sdo.ipc.Ipc');
    GateMP          = xdc.useModule('ti.sdo.ipc.GateMP');
}

/*!
 *  ======== instance$static$init ========
 */
function instance$static$init(obj, params)
{  
    GateAAMonitor.$logError("Static instances not supported yet",
            GateAAMonitor.common$, GateAAMonitor.common$.namedInstance);
}

/*!
 *  ======== queryMeta ========
 */
function queryMeta(qual)
{
    var rc = false;
    var IGateProvider = xdc.module('xdc.runtime.IGateProvider');

    switch (qual) {
        case IGateProvider.Q_BLOCKING:
            rc = true;
            break;
        case IGateProvider.Q_PREEMPTING:
            rc = true;
            break;
        default:
           GateAAMonitor.$logWarning("Invalid quality.", this, qual);
           break;
    }

    return (rc);
}

/*!
 *  ======== sharedMemReqMeta ========
 */
function sharedMemReqMeta(params)
{
    GateAAMonitor.$logError("Static instances not supported yet",
            GateAAMonitor.common$, GateAAMonitor.common$.namedInstance);
}

/*!
 *  ======== getNumResources ========
 */
function getNumResources()
{
    return (this.numInstances);
}

/*
 *************************************************************************
 *                       ROV View functions
 *************************************************************************
 */

/*
 *  ======== getRemoteStatus$view ========
 */
function getRemoteStatus$view(handle)
{
    var Program         = xdc.useModule('xdc.rov.Program');

    try {
        var view = Program.scanHandleView('ti.sdo.ipc.gates.GateAAMonitor',
                                          $addr(handle), 'Basic');
        return ("Entered by " + view.enteredBy); 
    }
    catch(e) {
        throw("ERROR: Couldn't scan GateAAMonitor handle view: " + e);
    }
}

/*!
 *  ======== viewInitBasic ========
 */
function viewInitBasic(view, obj)
{
    var Ipc             = xdc.useModule('ti.sdo.ipc.Ipc');
    var GateAAMonitor   = xdc.useModule('ti.sdo.ipc.gates.GateAAMonitor');
    var ScalarStructs   = xdc.useModule('xdc.rov.support.ScalarStructs');
    
    /* view.sharedAddr */
    view.sharedAddr = "0x" + Number(obj.sharedAddr).toString(16);
    
    /* view.nested */
    view.nested = obj.nested;
    
    /* view.enteredBy */
    try {
        var sstruct_status = Program.fetchStruct(ScalarStructs.S_Bits32$fetchDesc, 
                                                 obj.sharedAddr.$addr, false);
        var status = sstruct_status.elem;
        if (status > 0) {
            view.enteredBy = "CORE" + (status - 1);
        }
        else {
            view.enteredBy = "[free]";
        }
    }
    catch(e) {
        view.$status["enteredBy"] = 
            "Error: could not fetch status data from shared memory: " + e;
    }
}
/*
 *  @(#) ti.sdo.ipc.gates; 1, 0, 0, 0,142; 4-9-2010 18:38:19; /db/vtree/library/trees/ipc/ipc-d23x/src/
 */

