/* 
 * Copyright (c) 2010
 * Texas Instruments
 *
 *  All rights reserved.  Property of Texas Instruments
 *  Restricted rights to use, duplicate or disclose this code are
 *  granted through contract.
 * 
 * */
/*
 *  ======== GateHWSem.xdc ========
 *
 */

package ti.sdo.ipc.gates;

import xdc.runtime.Error;
import xdc.runtime.Assert;
import xdc.runtime.IGateProvider;
import xdc.runtime.Diags;
import xdc.runtime.Log;

import ti.sdo.ipc.interfaces.IGateMPSupport;

/*!
 *  ======== GateHWSem ========
 *  Multiprocessor gate that utilizes a hardware semaphore
 */
@ModuleStartup
@InstanceInitError
@InstanceFinalize

module GateHWSem inherits IGateMPSupport
{
    /*! @_nodoc */
    metaonly struct BasicView {
        Ptr     semNum;
        UInt    nested;
        String  enteredBy;      /* Which core has entered the hw sem */
    }

    /*!
     *  ======== rovViewInfo ========
     *  @_nodoc
     */
    @Facet
    metaonly config xdc.rov.ViewInfo.Instance rovViewInfo = 
        xdc.rov.ViewInfo.create({
            viewMap: [
                ['Basic', 
                    {
                        type: xdc.rov.ViewInfo.INSTANCE,
                        viewInitFxn: 'viewInitBasic',
                        structName: 'BasicView'
                    }
                ],
            ]
        });

    /*!
     *  ======== A_invalidParams ========
     *  Asserted when insufficient information is passed to {@link #open}
     */
    config Assert.Id A_invalidParams  = {
        msg: "A_invalidParams: Need to supply either a name or a semaphore Number"
    };
    
    /*!
     *  ======== A_invProtectionLevel ========
     *  Asserted when an invalid protection level is encountered
     */
    config Assert.Id A_invProtectionLevel  = {
        msg: "A_invProtectionLevel: Unknown level of local protection"
    };
    
    /*!
     *  ======== A_invSemNum ========
     *  Asserted when supplied semNum is invalid for the relevant device
     */
    config Assert.Id A_invSemNum  = {
        msg: "A_invSemNum: Invalid hardware semaphore number"
    };

instance:    

internal:

    /*! Initialize the hardware semaphore when the creator is created */
    Void postInit(Object *obj); 

    /*! Device-specific base address for HW Semaphore subsystem */
    config Ptr baseAddr;
    
    /*! Device-specific query offset for HW Semaphore subsystem (for ROV) */
    config Ptr queryAddr;
    
    /*! Device-specific number of semphores in the HW Semaphore subsystem */
    config UInt numSems;

    struct Instance_State {
        UInt                     semNum;    /* The sem number being used */
        UInt                     nested;    /* For nesting */        
        IGateProvider.Handle     localGate;
    };
}
/*
 *  @(#) ti.sdo.ipc.gates; 1, 0, 0, 0,142; 4-9-2010 18:38:19; /db/vtree/library/trees/ipc/ipc-d23x/src/
 */

