/* 
 * Copyright (c) 2010
 * Texas Instruments
 *
 *  All rights reserved.  Property of Texas Instruments
 *  Restricted rights to use, duplicate or disclose this code are
 *  granted through contract.
 * 
 * */
/*
 *  ======== GateHWSem.xs ========
 *
 */
 
var GateHWSem   = null;
var GateMP      = null;
var Ipc         = null;

/*!
 *  ======== module$use ========
 */
function module$use()
{
    GateHWSem = this;
    
    var Settings = xdc.module("ti.sdo.ipc.family.Settings");
    var devCfg = Settings.getGateHWSemSettings();
    GateHWSem.baseAddr      = devCfg.baseAddr;
    GateHWSem.queryAddr     = devCfg.queryAddr;
    GateHWSem.numSems       = devCfg.numSems;
    
    GateMP = xdc.useModule('ti.sdo.ipc.GateMP');
    
    /* Asserts, errors, etc */
    Ipc = xdc.useModule('ti.sdo.ipc.Ipc');
}

/*
 *  ======== getNumResources ========
 */
function getNumResources()
{
    return (GateHWSem.numSems);
}

/*
 *************************************************************************
 *                       ROV View functions
 *************************************************************************
 */

/*
 *  ======== getRemoteStatus$view ========
 */
function getRemoteStatus$view(handle)
{
    var Program         = xdc.useModule('xdc.rov.Program');

    try {
        var view = Program.scanHandleView('ti.sdo.ipc.gates.GateHWSem',
                                          $addr(handle), 'Basic');
        return ("Entered by " + view.enteredBy); 
    }
    catch(e) {
        throw("ERROR: Couldn't scan GateHWSem handle view: " + e);
    }
    
    return (status);
}
 
/*
 *  ======== viewInitBasic ========
 */
function viewInitBasic(view, obj)
{
    var GateHWSem       = xdc.useModule('ti.sdo.ipc.gates.GateHWSem');
    var ScalarStructs   = xdc.useModule('xdc.rov.support.ScalarStructs');
    
    /* view.semNum */
    view.semNum = obj.semNum;
    
    /* view.nested */
    view.nested = obj.nested;
    
    /* view.enteredBy */
    try {
        var modCfg = Program.getModuleConfig('ti.sdo.ipc.gates.GateHWSem');
        var semQueryAddr = $addr(Number(modCfg.queryAddr) + obj.semNum * 4);

        var sstruct_status = Program.fetchStruct(
                                ScalarStructs.S_Bits32$fetchDesc,
                                semQueryAddr, false);
        var status = sstruct_status.elem;
        if (status & 0x1) {
            view.enteredBy = "[free]";
        }
        else {
            var coreId = (status & 0x0000ff00) >> 8;
            view.enteredBy = "CORE" + coreId;
        }
    }
    catch(e) {
        view.$status["enteredBy"] = 
            "Error: could not fetch query data: " + e;
    }
}

/*
 *  @(#) ti.sdo.ipc.gates; 1, 0, 0, 0,142; 4-9-2010 18:38:19; /db/vtree/library/trees/ipc/ipc-d23x/src/
 */

