/* 
 * Copyright (c) 2010
 * Texas Instruments
 *
 *  All rights reserved.  Property of Texas Instruments
 *  Restricted rights to use, duplicate or disclose this code are
 *  granted through contract.
 * 
 * */
/*
 *  ======== GateHWSpinlock.xdc ========
 *
 */

package ti.sdo.ipc.gates;

import xdc.runtime.Error;
import xdc.runtime.Assert;
import xdc.runtime.IGateProvider;
import xdc.runtime.Diags;
import xdc.runtime.Log;

import ti.sdo.ipc.interfaces.IGateMPSupport;

/*!
 *  ======== GateHWSpinlock ========
 *  Multiprocessor gate that utilizes a hardware spinlock
 */
@InstanceInitError

module GateHWSpinlock inherits IGateMPSupport
{
    /*!
     *  ======== BasicView ========
     *  @_nodoc
     */
    metaonly struct BasicView {
        UInt    lockNum;
        UInt    nested;        
    }

    /*!
     *  ======== rovViewInfo ========
     *  @_nodoc
     */
    @Facet
    metaonly config xdc.rov.ViewInfo.Instance rovViewInfo = 
        xdc.rov.ViewInfo.create({
            viewMap: [
                ['Basic', 
                    {
                        type: xdc.rov.ViewInfo.INSTANCE,
                        viewInitFxn: 'viewInitBasic',
                        structName: 'BasicView'
                    }
                ],
            ]
        });

    /*!
     *  ======== LM_enter ========
     *  Logged on gate enter
     */
    config Log.Event LM_enter = {
        mask: Diags.USER1,
        msg: "LM_enter: Gate (lockNum = %d) entered, returning key = %d"
    };

    /*!
     *  ======== LM_leave ========
     *  Logged on gate leave
     */
    config Log.Event LM_leave = {
        mask: Diags.USER1,
        msg: "LM_leave: Gate (lockNum = %d) left using key = %d"
    };

    /*!
     *  ======== LM_create ========
     *  Logged on gate create
     */
    config Log.Event LM_create = {
        mask: Diags.USER1,
        msg: "LM_create: Gate (lockNum = %d) created"
    };

    /*!
     *  ======== LM_open ========
     *  Logged on gate open
     */
    config Log.Event LM_open = {
        mask: Diags.USER1,
        msg: "LM_open: Remote gate (lockNum = %d) opened"
    };

    /*!
     *  ======== LM_delete ========
     *  Logged on gate deletion
     */
    config Log.Event LM_delete = {
        mask: Diags.USER1,
        msg: "LM_delete: Gate (lockNum = %d) deleted"
    };

    /*!
     *  ======== LM_close ========
     *  Logged on gate close
     */
    config Log.Event LM_close = {
        mask: Diags.USER1,
        msg: "LM_close: Gate (lockNum = %d) closed"
    };

    /*!
     *  ======== A_invalidParams ========
     *  Asserted when insufficient information is passed to {@link #open}
     */
    config Assert.Id A_invalidParams  = {
        msg: "A_invalidParams: Need to supply either a name or a spinlock Number"
    };
    
    /*!
     *  ======== A_invProtectionLevel ========
     *  Asserted when an invalid protection level is encountered
     */
    config Assert.Id A_invProtectionLevel  = {
        msg: "A_invProtectionLevel: Unknown level of local protection"
    };
    
    /*!
     *  ======== A_invSpinLockNum ========
     *  Assert raised when provided lockNum is invalid for the relevant device
     */
    config Assert.Id A_invSpinLockNum  = {
        msg: "A_invSpinLockNum: Invalid hardware spinlock number"
    };
    
    /*! Device-specific base address for HW Semaphore subsystem */
    config Ptr baseAddr = null;

instance:    

internal:
   
    /*! Device-specific number of semphores in the HW Semaphore subsystem */
    config UInt numLocks;

    struct Instance_State {
        UInt            lockNum;   /* The lock number being used */
        UInt            nested;    /* For nesting */
        IGateProvider.Handle     localGate;
    };
}
/*
 *  @(#) ti.sdo.ipc.gates; 1, 0, 0, 0,142; 4-9-2010 18:38:19; /db/vtree/library/trees/ipc/ipc-d23x/src/
 */

