/* 
 * Copyright (c) 2010
 * Texas Instruments
 *
 *  All rights reserved.  Property of Texas Instruments
 *  Restricted rights to use, duplicate or disclose this code are
 *  granted through contract.
 * 
 * */
/*
 *  ======== GatePeterson.xs ========
 *
 */

var GatePeterson = null;
var MultiProc    = null;
var Cache        = null;
var Ipc          = null;
var GateMP       = null;

/*!
 *  ======== module$use ========
 */
function module$use()
{
    GatePeterson = this;
    MultiProc    = xdc.useModule('ti.sdo.utils.MultiProc');
    Cache        = xdc.useModule('ti.sysbios.hal.Cache');
    Ipc          = xdc.useModule('ti.sdo.ipc.Ipc');
    GateMP       = xdc.useModule('ti.sdo.ipc.GateMP');
}

/*!
 *  ======== instance$static$init ========
 */
function instance$static$init(obj, params)
{  
    GatePeterson.$logError("Static instances not supported yet",
            GatePeterson.common$, GatePeterson.common$.namedInstance);
}

/*!
 *  ======== queryMeta ========
 */
function queryMeta(qual)
{
    var rc = false;
    var IGateProvider = xdc.module('xdc.runtime.IGateProvider');

    switch (qual) {
        case IGateProvider.Q_BLOCKING:
            rc = false;
            break;
        case IGateProvider.Q_PREEMPTING:
            rc = true;
            break;
        default:
           GatePeterson.$logWarning("Invalid quality.", this, qual);
           break;
    }

    return (rc);
}

/*
 *  ======== getNumResources ========
 */
function getNumResources()
{
    return (this.numInstances);
}

/*
 *************************************************************************
 *                       ROV View functions
 *************************************************************************
 */

/*
 *  ======== getRemoteStatus$view ========
 */
function getRemoteStatus$view(handle)
{
    var Program         = xdc.useModule('xdc.rov.Program');
    var ScalarStructs   = xdc.useModule('xdc.rov.support.ScalarStructs');

    try {
        var view = Program.scanHandleView('ti.sdo.ipc.gates.GatePeterson',
                                          $addr(handle), 'Basic');
        if (view.gateOwner == "free") {
            return (view.gateOwner);
        }
        return ("Entered by " + view.gateOwner);
    }
    catch(e) {
        throw("ERROR: Couldn't scan GatePeterson handle view: " + e);
    }
}
 
/*
 *  ======== viewInitBasic ========
 */
function viewInitBasic(view, obj)
{
    var Ipc             = xdc.useModule('ti.sdo.ipc.Ipc');
    var GatePeterson    = xdc.useModule('ti.sdo.ipc.gates.GatePeterson');
    var ScalarStructs   = xdc.useModule('xdc.rov.support.ScalarStructs');

    /* view.objType */
    view.objType = Ipc.getObjTypeStr$view(obj.objType);
    
    /* view.nested */
    view.nested = obj.nested;
    
   try {
        attrs = Program.fetchStruct(GatePeterson.Attrs$fetchDesc,
                                    obj.attrs.$addr, false);
                                    
        view.creatorProcId = attrs.creatorProcId;
        view.openerProcId = attrs.openerProcId;
    }
    catch (e) {
        view.$status["creatorProcId"] = view.$status["openerProcId"] =
            "Error: could not fetch shared memory structure: " + e;
        throw (e);
    }
    
    try {
        var sstruct_flag0 = Program.fetchStruct(ScalarStructs.S_Bits16$fetchDesc, 
                                                obj.flag[0].$addr, false);
        var sstruct_flag1 = Program.fetchStruct(ScalarStructs.S_Bits16$fetchDesc, 
                                                obj.flag[1].$addr, false);
        var sstruct_turn  = Program.fetchStruct(ScalarStructs.S_Bits16$fetchDesc,
                                                obj.turn.$addr, false);
                                                
        var flag = [sstruct_flag0.elem, sstruct_flag1.elem];
        var turn = sstruct_turn.elem
        
        if (flag[1] == 1 && (turn == 1 || flag[0] == 0)) {
            /* Opener has the gate */
            view.gateOwner = "opener";
        }
        else if (flag[0] == 1 && (turn == 0 || flag[1] == 0)) {
            /* Creator has the gate */
            view.gateOwner = "creator";
        }
        else {
            view.gateOwner = "[free]";
        }
    }
    catch(e) {
        view.$status["gateOwner"] = 
            "Error: could not fetch turn/flag data from shared memory: " + e;
    }
    
}
/*
 *  @(#) ti.sdo.ipc.gates; 1, 0, 0, 0,142; 4-9-2010 18:38:19; /db/vtree/library/trees/ipc/ipc-d23x/src/
 */

