/* 
 * Copyright (c) 2010
 * Texas Instruments
 *
 *  All rights reserved.  Property of Texas Instruments
 *  Restricted rights to use, duplicate or disclose this code are
 *  granted through contract.
 * 
 * */
/*
 *  ======== HeapMultiBufMP.xs ========
 *
 */

var HeapMultiBufMP  = null;
var SharedRegion    = null;
var NameServer      = null;
var Ipc             = null;
var Cache           = null;
var GateMP          = null;

var instCount = 0;  /* use to determine if processing last instance */

/*
 *  ======== module$use ========
 */
function module$use()
{
    HeapMultiBufMP  = this;
    Memory          = xdc.useModule('xdc.runtime.Memory');
    NameServer      = xdc.useModule('ti.sdo.utils.NameServer');
    SharedRegion    = xdc.useModule('ti.sdo.ipc.SharedRegion');
    Ipc             = xdc.useModule('ti.sdo.ipc.Ipc');
    GateMP          = xdc.useModule('ti.sdo.ipc.GateMP');
    Cache           = xdc.useModule('ti.sysbios.hal.Cache');
}

/*
 *  ======== module$static$init ========
 */
function module$static$init(mod, params)
{
    mod.nameServer  = null;
    
    /* Setup nameserver */
    /* initialize the NameServer param to be used now or later */
    HeapMultiBufMP.nameSrvPrms.maxRuntimeEntries 
            = params.maxRuntimeEntries;
    HeapMultiBufMP.nameSrvPrms.tableSection = params.tableSection;
    HeapMultiBufMP.nameSrvPrms.maxNameLen   = params.maxNameLen;            

    /* 
     *  Get the current number of created static instances of this module.
     *  Note: if user creates a static instance after this point and
     *        expects to use NameServer, this is a problem. 
     */
    var instCount = this.$instances.length;

    /* create NameServer here only if no static instances are created */
    if (instCount == 0) {
        mod.nameServer = NameServer.create("HeapMultiBufMP",    
                                            HeapMultiBufMP.nameSrvPrms);
    }
}

/*
 *  ======== viewInitBasic ========
 */
function viewInitBasic(view, obj)
{
    var NameServer      = xdc.useModule('ti.sdo.utils.NameServer');
    var HeapMultiBufMP  = xdc.useModule('ti.sdo.ipc.heaps.HeapMultiBufMP');
    var Ipc             = xdc.useModule('ti.sdo.ipc.Ipc');
    var SharedRegion    = xdc.useModule('ti.sdo.ipc.SharedRegion');
    
    /* view.name */
    view.name = NameServer.getName$view("HeapMultiBufMP", 
        SharedRegion.getSRPtrMeta$view(obj.attrs));

    /* view.objType */
    view.objType = Ipc.getObjTypeStr$view(obj.objType);
    
    /* view.gate */
    view.gate = "0x" + Number(obj.gate.$addr).toString(16);
   
    try {
        var attrs = Program.fetchStruct(HeapMultiBufMP.Attrs$fetchDesc,
                                        obj.attrs.$addr, false);
        var totalSize = 0;
        for (var i = 0; i < attrs.numBuckets; i++) {
            totalSize += attrs.buckets[i].blockSize * 
                         attrs.buckets[i].numBlocks;
        }
        
        /* view.totalSize */
        view.totalSize = "0x" + Number(totalSize).toString(16);
        
        /* view.exact */
        view.exact = attrs.exact == 1 ? true : false;
        
        /* view.buf */
        view.buf = "0x" + Number(obj.buf.$addr).toString(16);
    }
    catch (e) {
        throw("Error: could not access shared memory: " + e);
    }
    
}

/*
 *  ======== viewInitData ========
 */
function viewInitData(view, obj)
{
    var HeapMultiBufMP = xdc.useModule('ti.sdo.ipc.heaps.HeapMultiBufMP');
    var SharedRegion   = xdc.useModule('ti.sdo.ipc.SharedRegion');
    var NameServer     = xdc.useModule('ti.sdo.utils.NameServer');    

    /* Display the instance label in the tree */
    view.label = NameServer.getName$view("HeapMultiBufMP", 
        SharedRegion.getSRPtrMeta$view(obj.attrs.$addr));        
    if (view.label == null) {
        view.label = "0x" + Number(obj.attrs.$addr).toString(16);
    }
    
    /* Fetch attrs struct */
    try {
        var attrs = Program.fetchStruct(HeapMultiBufMP.Attrs$fetchDesc,
                                        obj.attrs.$addr, false);
                                        
        for (i = 0; i < Number(attrs.numBuckets); i++) {
            var elem = Program.newViewStruct('ti.sdo.ipc.heaps.HeapMultiBufMP',
                                             'Buffer Information');
            elem.baseAddr       = "0x" + Number(SharedRegion.getPtrMeta$view(
                $addr(attrs.buckets[i].baseAddr))).toString(16);
            elem.blockSize      = attrs.buckets[i].blockSize;
            elem.align          = attrs.buckets[i].align;
            elem.numBlocks      = attrs.buckets[i].numBlocks;
            elem.numFreeBlocks  = attrs.buckets[i].numFreeBlocks;
            
            elem.minFreeBlocks  = attrs.buckets[i].minFreeBlocks == 0xffffffff
                                  ? -1 : attrs.buckets[i].minFreeBlocks;
            
            /* Add the element to the list. */
            view.elements.$add(elem);
        }
    }
    catch (e) {
        throw("Error: could not access shared memory: " + e);
    }
}
 
/*
 *  @(#) ti.sdo.ipc.heaps; 1, 0, 0, 0,139; 4-9-2010 18:38:21; /db/vtree/library/trees/ipc/ipc-d23x/src/
 */

