/* 
 * Copyright (c) 2010
 * Texas Instruments
 *
 *  All rights reserved.  Property of Texas Instruments
 *  Restricted rights to use, duplicate or disclose this code are
 *  granted through contract.
 * 
 * */
/*
 *  ======== IGateMPSupport.xdc ========
 *
 */

import xdc.runtime.Error;
import xdc.runtime.IGateProvider;

/*!
 *  ======== IGateMPSupport ========
 */
interface IGateMPSupport inherits IGateProvider {

    /*!
     *  Local protection enum
     *
     *  Must be the same GateMP. 
     */
    enum LocalProtect {
        LocalProtect_NONE      = 0,
        LocalProtect_INTERRUPT = 1,
        LocalProtect_TASKLET   = 2,
        LocalProtect_THREAD    = 3,
        LocalProtect_PROCESS   = 4
    };
    
    /*!
     *  ======== getNumResources ========
     *  Number of  gates instance within the module
     */
    metaonly UInt getNumResources();
    
    /*!
     *  ======== sharedMemReq ========
     *  Amount of shared memory required for creation of each instance
     *
     *  The value returned by this function may depend on the cache alignment
     *  requirements for the shared region from which memory will be used.
     *
     *  @param(params)      Pointer to the parameters that will be used in
     *                      the create.
     *
     *  @a(returns)         Number of MAUs needed to create the instance.
     */
    SizeT sharedMemReq(const Params *params);

    /*!
     *  ======== getRemoteStatus$view ========
     *  @_nodoc
     *  Returns the status of the remote gate
     *
     *  @b(returns)     Gate status
     */
    metaonly String getRemoteStatus$view(IGateProvider.Handle handle);
    
instance:
    /*! 
     *  Logical resource id
     */
    config UInt resourceId = 0;
    
    /*! @_nodoc
     *  ======== openFlag ========    
     */
    config Bool openFlag = false;
        
    /*!
     *  ======== regionId ========
     *  @_nodoc
     *  Shared Region Id
     * 
     *  The ID corresponding to the shared region in which this shared instance
     *  is to be placed.
     */
    config UInt16 regionId = 0;

    /*!
     *  ======== sharedAddr ========
     *  Physical address of the shared memory
     *
     *  The creator must supply the shared memory that will be used
     *  for maintaining shared state information.  This parameter is used
     *  only when {@link #Type} is set to {@link #Type_SHARED}
     */
    config Ptr sharedAddr = null;
    
    /*!
     *  ======== create ========     
     *  Create a remote gate instance
     */
    create(LocalProtect localProtect);
}
/*
 *  @(#) ti.sdo.ipc.interfaces; 1, 0, 0, 0,298; 4-9-2010 18:38:24; /db/vtree/library/trees/ipc/ipc-d23x/src/
 */

