/* 
 * Copyright (c) 2010
 * Texas Instruments
 *
 *  All rights reserved.  Property of Texas Instruments
 *  Restricted rights to use, duplicate or disclose this code are
 *  granted through contract.
 * 
 * */
/*
 *  ======== package.xs ========
 *
 */


/*
 *  ======== Package.getLibs ========
 *  This function is called when a program's configuration files are
 *  being generated and it returns the name of a library appropriate
 *  for the program's configuration.
 */

function getLibs(prog)
{
    var suffix;

    /* find a compatible suffix */
    if ("findSuffix" in prog.build.target) {
        suffix = prog.build.target.findSuffix(this);
    }
    else {
        suffix = prog.build.target.suffix;
    }

    var name = this.$name + ".a" + suffix;
    var lib = "";

    lib = "lib/" + this.profile + "/" + name;
    if (java.io.File(this.packageBase + lib).exists()) {
        return lib;
    }

    /* all ti.targets return whole_program_debug library by default */
    if (prog.build.target.$name.match(/^ti\.targets\./)) {
        lib = "lib/" + "whole_program_debug/" + name;
        if (java.io.File(this.packageBase + lib).exists()) {
            return lib;
        }
    }

    /* all other targets, return release library by default */
    else {
        lib = "lib/" + "release/" + name;
        if (java.io.File(this.packageBase + lib).exists()) {
            return lib;
        }
    }

    /* could not find any library, throw exception */
    throw Error("Library not found: " + name);
}

/*
 *  ======== package.close ========
 */
function close()
{    
    if (xdc.om.$name != 'cfg') {
        return;
    }
}
/*
 *  @(#) ti.sdo.ipc.interfaces; 1, 0, 0, 0,298; 4-9-2010 18:38:25; /db/vtree/library/trees/ipc/ipc-d23x/src/
 */

