/* 
 * Copyright (c) 2010
 * Texas Instruments
 *
 *  All rights reserved.  Property of Texas Instruments
 *  Restricted rights to use, duplicate or disclose this code are
 *  granted through contract.
 * 
 * */
/*
 *  ======== IInterrupt.xdc ========
 *
 */
 
/*!
 *  ======== IInterrupt ========
 *  Interface for the inter-processor interrupts
 */
interface IInterrupt {

    struct IntInfo {
        UInt  localIntId;
        UInt  remoteIntId;
        UInt  intVectorId;
    }
    
    /*!
     *  ======== intEnable ========
     *  Enables the interrupt corresponding to intId
     *
     *  @param(remoteProcId)  Remote MultiProc Id
     *  @param(intInfo)       Information needed to configure interrupt line  
     */
    Void intEnable(UInt16 remoteProcId, IntInfo *intInfo);
        
    /*!
     *  ======== intDisable ========
     *  Disables the interrupt corresponding to intId
     *
     *  @param(remoteProcId)  Remote MultiProc Id
     *  @param(intInfo)       Information needed to configure interrupt line  
     */     
    Void intDisable(UInt16 remoteProcId, IntInfo *intInfo);
    
    /*!
     *  ======== intRegister ========
     *  Register an interrupt line to a remote processor
     *
     *  @param(remoteProcId)  Remote MultiProc Id
     *  @param(intInfo)       Information needed to configure interrupt line  
     *  @param(func)          Function to register.
     *  @param(arg)           Argument that will be passed to func
     */
    Void intRegister(UInt16 remoteProcId, IntInfo *intInfo, Fxn func, UArg arg);
    
    /*!
     *  ======== intUnregister ========
     *  Unregister an interrupt line to a remote processor
     *
     *  @param(remoteProcId)  Remote MultiProc Id
     *  @param(intInfo)       Information needed to configure interrupt line
     */
    Void intUnregister(UInt16 remoteProcId, IntInfo *intInfo);
    
    /*!
     *  ======== intSend ========
     *  Send interrupt to the remote processor
     *
     *  @param(remoteProcId)  Remote MultiProc Id
     *  @param(intInfo)       Information needed to configure interrupt line  
     *  @param(arg)           Argument for sending interrupt.     
     */
    Void intSend(UInt16 remoteProcId, IntInfo *intInfo, UArg arg);
    
    /*!
     *  @_nodoc
     *  Post an interrupt locally.
     *
     *  Used to simulate receiving an interrupt from a remote (source) 
     *  processor
     *
     *  @param(remoteProcId)  Source MultiProc Id
     *  @param(intInfo)       Information needed to configure interrupt line  
     *  @param(arg)           Argument for sending interrupt.     
     */
    Void intPost(UInt16 srcProcId, IntInfo *intInfo, UArg arg);
     
    /*!
     *  ======== intClear ========
     *  Clear interrupt
     *
     *  @param(remoteProcId)  Remote MultiProc Id
     *  @param(intInfo)       Information needed to configure interrupt line  
     *
     *  @b(returns)           Value (if any) of the interrupt before 
     *                        it was cleared
     */
    UInt intClear(UInt16 remoteProcId, IntInfo *intInfo);
}
/*
 *  @(#) ti.sdo.ipc.notifyDrivers; 1, 0, 0, 0,219; 4-9-2010 18:38:28; /db/vtree/library/trees/ipc/ipc-d23x/src/
 */

