/* 
 * Copyright (c) 2010
 * Texas Instruments
 *
 *  All rights reserved.  Property of Texas Instruments
 *  Restricted rights to use, duplicate or disclose this code are
 *  granted through contract.
 *
 * */
/*
 *  ======== NotifyDriverShm.xs ================
 *
 */

var NotifyDriverShm  = null;
var List             = null;
var MultiProc        = null;
var Notify           = null;
var Ipc              = null;
var Cache            = null;
var Memory           = null;
var SharedRegion     = null;

/*
 *  ======== module$use ========
 */
function module$use()
{
    NotifyDriverShm = this;
    List            = xdc.useModule("ti.sdo.utils.List");
    MultiProc       = xdc.useModule("ti.sdo.utils.MultiProc");
    Notify          = xdc.useModule("ti.sdo.ipc.Notify");
    Ipc             = xdc.useModule("ti.sdo.ipc.Ipc");
    SharedRegion    = xdc.useModule("ti.sdo.ipc.SharedRegion");
    Cache           = xdc.useModule("ti.sysbios.hal.Cache");
    Memory          = xdc.useModule("xdc.runtime.Memory");

    if (NotifyDriverShm.InterruptProxy == null) {
        var Settings = xdc.module("ti.sdo.ipc.family.Settings");
        var interruptDelegate = Settings.getDefaultInterruptDelegate();
        NotifyDriverShm.InterruptProxy = xdc.useModule(interruptDelegate);
    }
}

/*
 *************************************************************************
 *                       ROV View functions
 *************************************************************************
 */

/*
 *  ======== viewInitBasic ========
 */
function viewInitBasic(view, obj)
{
    var MultiProc = xdc.useModule('ti.sdo.utils.MultiProc');
    
    /* view.remoteProcName */
    try {
        view.remoteProcName = MultiProc.getName$view(obj.remoteProcId);
    }
    catch(e) {
        Program.displayError(view, 'remoteProcName', 
                             "Problem retrieving proc name: " + e);
    }


    /* view.cacheEnabled */
    view.cacheEnabled = obj.cacheEnabled;
}

/*
 *  ======== getEventData ========
 *  Helper function for use within viewInitData
 */
function getEventData(view, obj, procCtrlPtr, eventChartPtr)
{
    var NotifyDriverShm = 
        xdc.useModule('ti.sdo.ipc.notifyDrivers.NotifyDriverShm');
    var modCfg = Program.getModuleConfig('ti.sdo.ipc.Notify');
    
    if (procCtrlPtr == obj.selfProcCtrl) {
        var procName = "[local]";
    }
    else {
        var procName = "[remote]";
    }
    
    try {
        var procCtrl = Program.fetchStruct(NotifyDriverShm.ProcCtrl$fetchDesc,
                                           procCtrlPtr);
    }
    catch(e) {
        throw (new Error("Error fetching procCtrl struct from shared memory"));
    }
        
    /* For each possible eventId... */
    for (var eventId = 0; eventId < modCfg.numEvents; eventId++) {
        if (procCtrl.eventRegMask & (1 << eventId)) {
            /* The event is registered */
            var elem = Program.newViewStruct(
                'ti.sdo.ipc.notifyDrivers.NotifyDriverShm', 
                'Events');
                
            elem.eventId = eventId;
            elem.procName = procName;
            elem.enabled = procCtrl.eventEnableMask & (1 << eventId);
            
            try {
                var eventEntry = Program.fetchStruct(
                    NotifyDriverShm.EventEntry$fetchDesc,
                    $addr(Number(eventChartPtr) + obj.eventEntrySize * 
                          eventId));
                
            }
            catch (e) {
                throw (new Error("Error fetching eventEntry from shared memory"));
            }
            
            elem.flagged = (eventEntry.flag == NotifyDriverShm.UP);
            elem.payload = eventEntry.payload;
            
            /* Create a new row in the instance data view */
            view.elements.$add(elem);
        }
    }
}


/*
 *  ======== viewInitData ========
 *  Instance data view.
 */
function viewInitData(view, obj)
{
    var MultiProc = xdc.useModule('ti.sdo.utils.MultiProc');
    try {
        var notifyObj = Program.scanHandleView('ti.sdo.ipc.Notify',
            obj.notifyHandle, 'Basic');
    }
    catch (e) {
        throw (new Error("Error fetching Notify instance view"));
    }

    /* Display the instance label in the tree */
    view.label = "procId = " + obj.remoteProcId + " lineId = " + 
        notifyObj.lineId;

    /* Fetch self/other procCtrl's */
    try {
        var procCtrl = Program.fetchStruct(obj.selfProcCtrl$fetchDesc,
                                           obj.selfProcCtrl);
    }
    catch(e) {
        throw (new Error("Error fetching procCtrl struct from shared memory"));
    }
    
    /* Get event data for the local processor */
    getEventData(view, obj, obj.selfProcCtrl, obj.selfEventChart);
    
    /* Get event data for the remote processor */
    getEventData(view, obj, obj.otherProcCtrl, obj.otherEventChart);
    
}
/*
 *  @(#) ti.sdo.ipc.notifyDrivers; 1, 0, 0, 0,219; 4-9-2010 18:38:29; /db/vtree/library/trees/ipc/ipc-d23x/src/
 */

