/* 
 * Copyright (c) 2010
 * Texas Instruments
 *
 *  All rights reserved.  Property of Texas Instruments
 *  Restricted rights to use, duplicate or disclose this code are
 *  granted through contract.
 * 
 * */
/*
 *  ======== TransportShmSetup.c ========
 */

#include <xdc/std.h>
#include <xdc/runtime/Assert.h>

#include <ti/sdo/ipc/transports/TransportShm.h>

#include "package/internal/TransportShmSetup.xdc.h"

#include <ti/sdo/ipc/_Ipc.h>
#include <ti/sdo/ipc/_GateMP.h>
#include <ti/sdo/ipc/_MessageQ.h>
#include <ti/sdo/ipc/_Notify.h>
#include <ti/sdo/ipc/_SharedRegion.h>
#include <ti/sdo/utils/_MultiProc.h>

/*
 *  ======== TransportShmSetup_attach ========
 */
Int TransportShmSetup_attach(UInt16 remoteProcId, Ptr sharedAddr)
{
    TransportShm_Params params;
    TransportShm_Handle handle;
    Int status = MessageQ_E_FAIL;
    
    /* init the transport parameters */
    TransportShm_Params_init(&params);
    params.gate = GateMP_getDefaultRemote();
    params.sharedAddr = sharedAddr;
     
    /* make sure notify driver has been created */
    if (Notify_intLineRegistered(remoteProcId, 0)) {
        /* create if self < remoteProcId, otherwise open */
        if (MultiProc_self() < remoteProcId) {
            /* create the transport */
            handle = TransportShm_create(remoteProcId, &params, NULL);

            if (handle != NULL) {
                TransportShmSetup_module->handles[remoteProcId] = handle;
                status = MessageQ_S_SUCCESS;
        }
        }
        else {
            status = TransportShm_openByAddr(params.sharedAddr, &handle, NULL);
            TransportShmSetup_module->handles[remoteProcId] = handle;
        }
    }

    return (status);
}

/*
 *  ======== TransportShmSetup_detach ========
 */
Int TransportShmSetup_detach(UInt16 remoteProcId)
{
    TransportShm_Handle handle;
    
    handle = TransportShmSetup_module->handles[remoteProcId];
    
    /* Trying to detach an un-attached processor should fail */
    if (handle == NULL) {
        return (MessageQ_E_FAIL);
    }
    
    /* Unregister the instance */
    TransportShmSetup_module->handles[remoteProcId] = NULL;

    /* Delete/close the transport */
    if (MultiProc_self() < remoteProcId) {
        TransportShm_delete(&handle);
    }
    else {
        TransportShm_close(&handle);
    }

    return (MessageQ_S_SUCCESS);
}

/*
 *  ======== TransportShmSetup_isRegistered ========
 */
Bool TransportShmSetup_isRegistered(UInt16 remoteProcId)
{
    Bool registered;
    
    registered = (TransportShmSetup_module->handles[remoteProcId] != NULL);

    return (registered);
}

/*
 *  ======== TransportShmSetup_sharedMemReq ========
 */
SizeT TransportShmSetup_sharedMemReq(Ptr sharedAddr)
{
    TransportShm_Params params;
    SizeT memReq = 0;

    if (MultiProc_numProcessors > 1) {
        params.sharedAddr = sharedAddr;
        memReq += TransportShm_sharedMemReq(&params);
    }
    
    return(memReq);
}

/*
 */
/*
 *  @(#) ti.sdo.ipc.transports; 1, 0, 0, 0,109; 4-9-2010 18:38:35; /db/vtree/library/trees/ipc/ipc-d23x/src/
 */

