/* 
 * Copyright (c) 2010
 * Texas Instruments
 *
 *  All rights reserved.  Property of Texas Instruments
 *  Restricted rights to use, duplicate or disclose this code are
 *  granted through contract.
 * 
 * */
/*
 *  ======== List.xs ========
 *
 */

var List = null;

/*
 *  ======== module$meta$init ========
 */
function module$meta$init()
{
    /* Only process during "cfg" phase */
    if (xdc.om.$name != "cfg") {
        return;
    }

    List = this;
    
    /* to minimize object size */
    List.common$.namedInstance = false;
}

/*
 *  ======== instance$static$init ========
 */
function instance$static$init(obj, params)
{
    obj.elem.next = obj.elem.prev = obj.elem;
    
    /* Add all the elem that we placed on the metaList */
    for (var i = 0; i < params.metaList.length; i++) {        
         this.putMeta(params.metaList[i]);        
    }
}

/*
 *  ======== elemClearMeta ========
 */
function elemClearMeta(elem)
{
    elem.next = elem.prev = elem;
}

/*
 *  ======== putMeta ========
 */
function putMeta(elem)
{
    var obj = this.$object;
    
    /* If the static$init has not been called, add to metaList*/
    if (obj.elem.prev === undefined) {        
        this.metaList.$add(elem);
    }
    else {
       /* Add directly into the object */
       elem.next = obj.elem;
       elem.prev = obj.elem.prev;
       obj.elem.prev.next = elem;
       obj.elem.prev = elem;
    }
}

/*
 *  ======== module$validate ========
 */
function module$validate()
{
    if (List.common$.namedInstance == true) {
        List.$logError("The List module does not support namedInstances.", 
        List.common$, List.common$.namedInstance);
    }
}

/*
 *  ======== viewInitInstance ========
 */
function viewInitInstance(view, obj)
{
    var List = xdc.useModule('ti.sdo.utils.List');
    var Program = xdc.useModule('xdc.rov.Program');
    
    view.label = Program.getShortName(obj.$label);
    
    /* 
     * To check for loops, store each address as a key in a map,
     * then with each new address check first if it is already in
     * the map.
     */
    var addrs = {};
    
    var e = obj.elem;
    while (Number(e.next) != Number(obj.$addr)) {
        
        /* Before fetching the next element, verify we're not in a loop. */
        if (e.next in addrs) {
            view.$status["elems"] = "List contains loop. Element " + e.$addr + " points to element " + e.next;
            break;
        }
        
        /* Fetch the next element and add it to the array of elements. */
        e = Program.fetchStruct(List.Elem$fetchDesc, e.next);
        view.elems.$add(e.$addr);
        
        /* 
         * Add the address to a map so we can check for loops. 
         * The value 'true' is just a placeholder to make sure the address
         * is in the map.
         */
        addrs[e.$addr] = true;
    }
}
/*
 *  @(#) ti.sdo.utils; 1, 0, 0, 0,372; 4-9-2010 18:38:38; /db/vtree/library/trees/ipc/ipc-d23x/src/
 */

