/* 
 * Copyright (c) 2010
 * Texas Instruments
 *
 *  All rights reserved.  Property of Texas Instruments
 *  Restricted rights to use, duplicate or disclose this code are
 *  granted through contract.
 * 
 * */
/*
 *  ======== MultiProc.c ========
 *  Implementation of functions specified in MultiProc.xdc.
 */

#include <xdc/std.h>
#include <string.h>
#include <xdc/runtime/Assert.h>
#include <xdc/runtime/Startup.h>

#include "package/internal/MultiProc.xdc.h"

#include <ti/sdo/utils/_MultiProc.h>

#ifdef __ti__
    #pragma FUNC_EXT_CALLED(MultiProc_getId);
    #pragma FUNC_EXT_CALLED(MultiProc_getName);
    #pragma FUNC_EXT_CALLED(MultiProc_getNumProcessors);
    #pragma FUNC_EXT_CALLED(MultiProc_self);
    #pragma FUNC_EXT_CALLED(MultiProc_setLocalId);
#endif

/*
 *************************************************************************
 *                      Module functions
 *************************************************************************
 */

/*
 *  ======== MultiProc_getId ========
 */
UInt16 MultiProc_getId(String name)
{
    Int    i;
    UInt16 id;
    
    /* If the name is NULL, simply return the local id */
    if (name == NULL) {
        id = MultiProc_module->id;
    }
    else {
        id = MultiProc_INVALIDID;
        for (i = 0; i < MultiProc_numProcessors; i++) {
            if ((MultiProc_nameList[i] != NULL) &&
                (strcmp(name, MultiProc_nameList[i]) == 0)) {
                id = i;
            }
        }
    }
    return (id);
}

/*
 *  ======== MultiProc_getName ======== 
 */
String MultiProc_getName(UInt16 id)
{
    Assert_isTrue((id < MultiProc_numProcessors), 
                   MultiProc_A_invalidMultiProcId);
    
    return (MultiProc_nameList[id]);
}

/*
 *  ======== MultiProc_getNumProcessors ======== 
 */
UInt16 MultiProc_getNumProcessors()
{
    return (MultiProc_numProcessors);
}

/*
 *  ======== MultiProc_getSlot ========
 */
UInt MultiProc_getSlot(UInt16 remoteProcId)
{
    UInt i, j, smallId, largeId;
    UInt slot = 0;

    if (remoteProcId > MultiProc_self()) {
        smallId = MultiProc_self();
        largeId = remoteProcId;
    }
    else {
        largeId = MultiProc_self();
        smallId = remoteProcId;
    }

    /* determine what offset to create for the remote Proc Id */
    for (i = 0; i < MultiProc_numProcessors; i++) {
        for (j = i + 1; j < MultiProc_numProcessors; j++) {
            if (smallId == i && largeId == j) {
                return(slot);
            }
            
            slot++;
        }
    }
                                                                                    return ((UInt)-1);
}

/*
 *  ======== MultiProc_self ========
 */
UInt16 MultiProc_self()
{
    return (MultiProc_module->id);
}

/*
 *  ======== MultiProc_setLocalId ======== 
 */
Int MultiProc_setLocalId(UInt16 id)
{   
    /* id must be less than the number of processors */
    Assert_isTrue((id < MultiProc_numProcessors), 
                   MultiProc_A_invalidMultiProcId);
    
    /* 
     *  Check the following
     *  1. Make sure the statically configured constant was invalid.
     *     To call setLocalId, the id must have been set to invalid.
     *  2. Make sure the call is made before module startup
     */
    if ((MultiProc_id == MultiProc_INVALIDID) && 
        (Startup_rtsDone() == FALSE)) {
       
        /* It is ok to set the id */       
        MultiProc_module->id = id;
        return (MultiProc_S_SUCCESS);
    }    
    
    return (MultiProc_E_FAIL);
}

/*
 */
/*
 *  @(#) ti.sdo.utils; 1, 0, 0, 0,372; 4-9-2010 18:38:38; /db/vtree/library/trees/ipc/ipc-d23x/src/
 */

