/* 
 * Copyright (c) 2010
 * Texas Instruments
 *
 *  All rights reserved.  Property of Texas Instruments
 *  Restricted rights to use, duplicate or disclose this code are
 *  granted through contract.
 * 
 * */
/*
 *  ======== MultiProc.xs ========
 *
 */

var MultiProc = null;

/*
 *  ======== module$use ========
 */
function module$use()
{    
    MultiProc = this;

    /* Make sure the name list is not too long... */
    if (MultiProc.nameList.length > MultiProc.numProcessors) {
        MultiProc.$logError("The name list is too long. numProcessors = " +
                            MultiProc.numProcessors, this);
    }
    else if (MultiProc.nameList.length < MultiProc.numProcessors) {
        /* If too short, fill in with nulls */
        var len = MultiProc.nameList.length;
        MultiProc.nameList.length = MultiProc.numProcessors;
        for (var i = len; i < MultiProc.numProcessors; i++) {
            MultiProc.nameList[i] = null;
        }
    }

    /*
     *  Make sure the id is ok (e.g. not equal to or greater than numProcessors)
     *  If it is INVALID (e.g. set at runtime) do not do the check.
     */
    if ((MultiProc.id != MultiProc.INVALIDID) &&
        (MultiProc.id >= MultiProc.numProcessors)) {

        MultiProc.$logError("The processor id (" + MultiProc.id +
            ") is larger than numProcessors (" + MultiProc.numProcessors +
            ")", this);
    }
    
}

/*
 *  ======== setName ========
 */
function setConfig(name, nameList) {
    MultiProc = this;
    
    MultiProc.nameList      = nameList;
    MultiProc.numProcessors = nameList.length;
    MultiProc.id            = MultiProc.INVALIDID;
   
    /* If name not null, it will be set at runtime */
    if (name != null) {
        /* Set MultiProc.id from the name */
        MultiProc.id = this.getIdMeta(name);
        if (MultiProc.id == MultiProc.INVALIDID) {
            MultiProc.$logError("The processor name (" + name +
                ") is not contained within the nameList", this);
        }
    }
}

/*
 *  ======== getIdMeta ========
 */
function getIdMeta(name) {
    MultiProc = this;
   
    var id = MultiProc.INVALIDID;
    
    if (name != null) {
        for (var i in MultiProc.nameList) {
            if (MultiProc.nameList[i] == name) {
                id  = Number(i);
            }
        }
    }
    else {
        /* Get our 'own' MultiProc id */
        id = MultiProc.id;
    }
    
    return (id);
}

/*
 *  ======== module$static$init ========
 */
function module$static$init(mod, params)
{
    mod.id = params.id;
}

/*
 *  ======== getName$view ========
 *  ROV helper function that returns a processor name given its id
 */
function getName$view(id)
{
    var name;
    
    /*
     * Scan in the MultiProc view so we have the mapping from processor id
     * to processor name.
     */
    try {
        var multiProcView = Program.scanModuleView('ti.sdo.utils.MultiProc',
                                                   'Module');
    }
    catch (e) {
        /*
         * If there was a problem scanning the MultiProc view, throw an error
         */
        throw("Error scanning MultiProc module view: " + String(e));
    }
    
    /* Check whether id is valid; throw an error if not */
    if (id > multiProcView.numProcessors) {
        throw("Invalid MultiProc id: " + id);
    }
    
    /* Since nameList is ordered by id, we can directly index the array */
    name = multiProcView.nameList[id];
    
    return (name);
}

/*
 *  ======== viewInitModule ========
 *  Display the module properties in ROV
 */
function viewInitModule(view, mod)
{
    var MultiProc = xdc.useModule('ti.sdo.utils.MultiProc');
    var Program = xdc.useModule('xdc.rov.Program');
    var multiprocModConfig =  Program.getModuleConfig(MultiProc.$name);
    
    view.id            = mod.id;    
    view.numProcessors = multiprocModConfig.numProcessors;
    
    /* Drop-down of the names */
    view.nameList.length = multiprocModConfig.nameList.length
    for (var i =0; i < multiprocModConfig.nameList.length; i++) {
        if (multiprocModConfig.nameList[i] != null)  {
            view.nameList[i] = multiprocModConfig.nameList[i];
        }
        else {
            view.nameList[i] = "[unnamed]";
        }
    }
}
/*
 *  @(#) ti.sdo.utils; 1, 0, 0, 0,372; 4-9-2010 18:38:38; /db/vtree/library/trees/ipc/ipc-d23x/src/
 */

