/* 
 * Copyright (c) 2010
 * Texas Instruments
 *
 *  All rights reserved.  Property of Texas Instruments
 *  Restricted rights to use, duplicate or disclose this code are
 *  granted through contract.
 * 
 * */
/*
 *  ======== multiProc.c ========
 *  This program demonstrates the following:
 *  Use Case 1: How to access local processor id
 *  Use Case 2: How to access processor id via a name
 *  Use Case 3: How to determine number of processors in the system
 */

#include <xdc/std.h>
#include <xdc/runtime/System.h>
#include <ti/ipc/MultiProc.h>

/*
 *  ======== main ========
 */
Int main(Int argc, Char* argv[])
{
    /* 
     *  =================================================================
     *  Use Case #1: Get local processor's processor id
     *     
     *  The code prints
     *  ---------------
     *  My processor id = 1      
     *  =================================================================
     */    
    System_printf("Use Case #1\n");
    
    /* Use NULL to get id for this processor */
    System_printf("My processor id = %d\n", MultiProc_self());
                   
    /* 
     *  =================================================================
     *  Use Case #2: Get "alpha"'s processor id
     *     
     *  The code prints
     *  ---------------
     *  Processor id for "alpha" = 0
     *  =================================================================
     */    
    System_printf("\nUse Case #2\n");
    
    System_printf("Processor id for \"alpha\" = %d\n", 
                   MultiProc_getId("alpha"));                    
 
    /* 
     *  =================================================================
     *  Use Case #3: Get the number of processors in the system
     *     
     *  The code prints
     *  ---------------
     *  Number of processors in the system = 2
     *  =================================================================
     */    
    System_printf("\nUse Case #3\n");
    
    System_printf("Number of processors in the system = %d\n", 
                   MultiProc_getNumProcessors());    
    
    return (0);
}

/*
 */
/*
 *  @(#) ti.sdo.utils.examples; 1, 0, 0, 0,106; 4-9-2010 18:39:57; /db/vtree/library/trees/ipc/ipc-d23x/src/
 */

