/* 
 * Copyright (c) 2010
 * Texas Instruments
 *
 *  All rights reserved.  Property of Texas Instruments
 *  Restricted rights to use, duplicate or disclose this code are
 *  granted through contract.
 * 
 * */
/*
 *  ======== multiProcSingleImage.c ========
 *  This example demonstrates how to dynamically set the processor id.
 *  This is useful when there is a single image that needs to be loaded
 *  on multiple cores.
 */

#include <xdc/std.h>
#include <xdc/runtime/System.h>
#include <ti/ipc/MultiProc.h>

Void setMyId()
{   
    UInt16 id;  
    Int status;
     
    /*
     *  Board specific determination of processor id. 
     *  Setting to 1 because this example needs to run on any platform.
     */
    id = 1;
    
    status = MultiProc_setLocalId(id);

    while (status == MultiProc_E_FAIL) {
        /* 
         *  Loop forever because there is an application design logic error due
         *  to at least one of the following reasons:
         *  1. The id was not set to MultiProc.INVALIDID in the .cfg file
         *  2. The id passed into MultiProc_setLocalId() is greater than or 
         *     equal to the numProcessors value.
         *  3. MultiProc_setLocalId() is called during or after module startup.
         */
    }
}

/*
 *  ======== main ========
 */
Int main(Int argc, Char* argv[])
{    
    /* Use NULL to get id for this processor */
    System_printf("My processor id = %d\n", MultiProc_self());
        
    return (0);
}

/*
 */
/*
 *  @(#) ti.sdo.utils.examples; 1, 0, 0, 0,106; 4-9-2010 18:39:57; /db/vtree/library/trees/ipc/ipc-d23x/src/
 */

